( function( $, api ) {

    "use strict";
    
    function hexToRGB(hex) {
        // Expand shorthand form (e.g. "03F") to full form (e.g. "0033FF")
        var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;
        hex = hex.replace(shorthandRegex, function(m, r, g, b) {
            return r + r + g + g + b + b;
        });

        var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
        return result ? parseInt(result[1], 16)+', '+parseInt(result[2], 16)+', '+parseInt(result[3], 16) : null;
    }

    // general setings

    api( 'irepair_logo', function( value ) {
        value.bind( function( to ) {
            var logo_container = document.getElementsByClassName( 'logo' )[0];
            var logo = logo_container.getElementsByTagName( 'img' )[0];
            if ( to != '' ) {
                logo.setAttribute( 'src', to );
            } else {
                logo.setAttribute( 'src', irepair_customizer_ajax.template+'/assets/img/logo.svg' );
            }
        } );
    } );

    api( 'irepair_logo_width', function( value ) {
        value.bind( function( to ) {
            if ( to ) {
                $( 'a.logo' ).css( 'height', to+'px' );
            }
        } );
    } );
    
    api( 'irepair_logo_sticky', function( value ) {
        value.bind( function( to ) {
            var logo_container = document.getElementsByClassName( 'logo-sticky' )[0];
            var logo = logo_container.getElementsByTagName( 'img' )[0];
            if ( to != '' ) {
                logo.setAttribute( 'src', to );
            } else {
                logo.setAttribute( 'src', irepair_customizer_ajax.template+'/assets/img/logo.svg' );
            }
        } );
    } );

    api( 'irepair_logo_sticky_height', function( value ) {
        value.bind( function( to ) {
            console.log(to);
            if ( to ) {
                $( 'a.logo-sticky' ).css( 'height', to+'px' );
            }
        } );
    } );

    // general colors

    api( 'irepair_accent_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--accent', to );
            } else {
                document.documentElement.style.setProperty( '--accent', irepair_customizer_ajax.accent_color );
            }
        } );
    } );

    api( 'irepair_compliment_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--compliment', to );
            } else {
                document.documentElement.style.setProperty( '--compliment', irepair_customizer_ajax.compliment_color );
            }
        } );
    } );

    api( 'irepair_additional_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--additional', to );
            } else {
                document.documentElement.style.setProperty( '--additional', irepair_customizer_ajax.additional_color );
            }
        } );
    } );

    api( 'irepair_section_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-section-bg-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-section-bg-color', irepair_customizer_ajax.section_bg_color );
            }
        } );
    } );

    api( 'irepair_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-bg-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-bg-color', irepair_customizer_ajax.bg_color );
            }
        } );
    } );

    api( 'irepair_white_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-white-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-white-color', irepair_customizer_ajax.white_color );
            }
        } );
    } );

    api( 'irepair_black_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-black-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-black-color', irepair_customizer_ajax.black_color );
            }
        } );
    } );

    //header color

    api( 'irepair_header_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-bg-color', hexToRGB(irepair_customizer_ajax[to]) );
            } else {
                document.documentElement.style.setProperty( '--pix-header-bg-color', irepair_customizer_ajax.header_bg_color );
            }
        } );
    } );
    
    api( 'irepair_header_opacity', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-opacity', to/100 );
            } else {
                document.documentElement.style.setProperty( '--pix-header-opacity', irepair_customizer_ajax.header_opacity );
            }
        } );
    } );
    
    api( 'irepair_submenu_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-submenu-bg-color', irepair_customizer_ajax[to] );
            } else {
                document.documentElement.style.setProperty( '--pix-submenu-bg-color', irepair_customizer_ajax.submenu_bg_color );
            }
        } );
    } );
    
    api( 'irepair_header_hover_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-hover-color', irepair_customizer_ajax[to] );
            } else {
                document.documentElement.style.setProperty( '--pix-header-hover-color', irepair_customizer_ajax.header_hover_color );
            }
        } );
    } );

    api( 'irepair_header_color', function( value ) {
        if( value.get() == 'text-inverse' ){
            $( 'header.header' ).addClass( 'text-inverse' ).removeClass( 'text-default' );
        } else {
            $( 'header.header' ).addClass( 'text-default' ).removeClass( 'text-inverse' );
        }
        value.bind( function( to ) {
            if ( to == 'text-inverse' ) {
                $( 'header.header' ).addClass( 'text-inverse' ).removeClass( 'text-default' );
            } else {
                $( 'header.header' ).addClass( 'text-default' ).removeClass( 'text-inverse' );
            }
        } );
    } );
    
    api( 'irepair_submenu_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-submenu-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-submenu-color', '#212529' );
            }
        } );
    } );

    api( 'irepair_header_button_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-button-bg-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-header-button-bg-color', irepair_customizer_ajax.button_bg_color );
            }
        } );
    } );

    api( 'irepair_header_button_opacity', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-button-opacity', to/100 );
            } else {
                document.documentElement.style.setProperty( '--pix-header-button-opacity', 1 );
            }
        } );
    } );

    api( 'irepair_header_button_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-button-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-header-button-color', irepair_customizer_ajax.button_color );
            }
        } );
    } );

    api( 'irepair_header_button_border_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-button-border-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-header-button-border-color', irepair_customizer_ajax.button_border_color );
            }
        } );
    } );
    
    api( 'irepair_header_sticky_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-sticky-bg-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-header-sticky-bg-color', '#ffffff' );
            }
        } );
    } );
    
    api( 'irepair_header_sticky_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-header-sticky-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-header-sticky-color', '#212529' );
            }
        } );
    } );
    
    api( 'irepair_sticky_submenu_bg_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-sticky-submenu-bg-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-sticky-submenu-bg-color', '#ffffff' );
            }
        } );
    } );
    
    api( 'irepair_sticky_submenu_color', function( value ) {
        value.bind( function( to ) {
            if ( to != '' ) {
                document.documentElement.style.setProperty( '--pix-sticky-submenu-color', to );
            } else {
                document.documentElement.style.setProperty( '--pix-sticky-submenu-color', '#212529' );
            }
        } );
    } );

    // header paddings/margins

    api( 'irepair_header_menu_paddings', function( value ) {
        value.bind( function( to ) {
            $('.pix-menu' ).css( 'padding', to+'px 0' );
        } );
    } );

    api( 'irepair_header_padding_top', function( value ) {
        value.bind( function( to ) {
            $('.header__page' ).css( 'padding-top', to+'px' );
        } );
    } );

    api( 'irepair_header_padding_bottom', function( value ) {
        value.bind( function( to ) {
            $('.header__page' ).css( 'padding-bottom', to+'px' );
        } );
    } );

    api( 'irepair_header_margin_bottom', function( value ) {
        value.bind( function( to ) {
            $('.pix-page-wide' ).css( 'padding-top', to+'px' );
        } );
    } );

    api( 'irepair_header_padding_top_prod', function( value ) {
        value.bind( function( to ) {
            $('.single-product .header__page' ).css( 'padding-top', to+'px' );
        } );
    } );

    api( 'irepair_header_padding_bottom_prod', function( value ) {
        value.bind( function( to ) {
            $('.single-product .header__page' ).css( 'padding-bottom', to+'px' );
        } );
    } );

    api( 'irepair_header_margin_bottom_prod', function( value ) {
        value.bind( function( to ) {
            $('.single-product .pix-page-wide' ).css( 'padding-top', to+'px' );
        } );
    } );

}( jQuery, wp.customize ) );