<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link    https://codex.wordpress.org/Template_Hierarchy
 *
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
    return;
}
?>

<div id="comments" class="comments">
    <?php if ( have_comments() ) : ?>
        <h3 class="comments__title">
        <?php
            $comments_count = get_comments_number();
            if ( $comments_count > 1 ) :
                printf( '%s %s', $comments_count, esc_html__( 'Comments', 'irepair' ) );
            else :
                printf( '%s %s', $comments_count, esc_html__( 'Comment', 'irepair' ) );
            endif;
            ?>
        </h3>

        <ul class="comments__list">
            <?php
                wp_list_comments( array(
                    'short_ping'   => true,
                    'style'        => 'ul',
                    'callback'     => 'irepair_comments_callback',
                    'end-callback' => 'irepair_comments_end_callback'
                ) );
            ?>
        </ul><!-- .comment-list -->

        <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>
            <nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
                <h1 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'irepair' ); ?></h1>
                <div class="nav-next"><?php next_comments_link( esc_html__( '&larr; Newer Comments', 'irepair' ) ); ?></div>
                <div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments &rarr;', 'irepair' ) ); ?></div>
            </nav><!-- #comment-nav-below -->
        <?php endif; // Check for comment navigation. ?>

    <?php endif; // Check for have_comments(). ?>

    <?php
    // If comments are closed and there are comments, let's leave a little note, shall we?
    if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>
        <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'irepair' ); ?></p>
    <?php endif; ?>

    <div class="comments__form">

        <?php
            $commenter = wp_get_current_commenter();
            $req = get_option( 'require_name_email' );

            $fields =  array(
                'author' => '<div class="row"><div class="col-sm-6 pr-sm-10 mb-20">' .
                '<input id="author" class="form-control" name="author" type="text" placeholder="' . esc_attr__( 'Your name', 'irepair' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" autocomplete="on" tabindex="2" ' . ( $req ? " required='required'" : '' ) . ' /></div>',
                'email'  => '<div class="col-sm-6 pl-sm-10 mb-20">'.
                '<input id="email" class="form-control" name="email" type="text" placeholder="' . esc_attr__( 'Your e-mail', 'irepair' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" autocomplete="on" tabindex="3" ' . ( $req ? " required='required'" : '' ) . ' /></div></div>',
            );

            $comments_args = array(
                'fields' =>  $fields,
                'comment_field' => '<textarea id="comment" class="form-control mb-20" name="comment" placeholder="' . esc_attr__( 'Comment', 'irepair' ) . ' *' . '" cols="5" rows="5" required="required"></textarea>',
                'title_reply_before' => '<h3 id="reply-title" class="comments__title">',
                'title_reply_after' => '</h3>',
                'submit_button' => '<button type="submit" class="btn btn-round btn-black" id="%2$s" name="%1$s">' . esc_html__( 'Post Comment', 'irepair' ) . ' <i class="pix-icon-caret-right"></i></button>',
            );

            comment_form( $comments_args );
         ?>

    </div>
</div>
