<?php

if ( class_exists( 'WP_Customize_Control' ) ) :

    class iRepair_Radio_Image_Control extends WP_Customize_Control {

        public function render_content() {

            if ( empty( $this->choices ) ) {
                return;
            }

            $input_id = '_customize-input-' . $this->id;
            $description_id = '_customize-description-' . $this->id;

            $name = '_customize-radio-' . $this->id;
            ?>
            <?php if ( ! empty( $this->label ) ) : ?>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <?php endif; ?>
            <?php if ( ! empty( $this->description ) ) : ?>
                <span id="<?php echo esc_attr( $description_id ); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
            <?php endif; ?>

            <ul class="controls pix-radio-img-container">
            <?php foreach ( $this->choices as $value => $label ) : ?>
                <?php $class = ( $this->value() == $value ) ? 'pix-radio-img pix-radio-img-selected' : 'pix-radio-img'; ?>
                <li>
                    <label for="<?php echo esc_attr( $input_id . '-radio-image-' . $value ); ?>">
                        <input
                            id="<?php echo esc_attr( $input_id . '-radio-image-' . $value ); ?>"
                            type="radio"
                            value="<?php echo esc_attr( $value ); ?>"
                            name="<?php echo esc_attr( $name ); ?>"
                            <?php $this->link(); ?>
                            <?php checked( $this->value(), $value ); ?>
                            />
                        <img src="<?php echo esc_url( $label ); ?>"" class="<?php echo esc_attr( $class ); ?>" />
                    </label>
                </li>
            <?php endforeach; ?>
            </ul>
            <?php
        }
    }

    class iRepair_Checkbox_Multiple_Control extends WP_Customize_Control {

        /**
         * The type of customize control being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'checkbox-multiple';

        public function render_content() {

            if ( empty( $this->choices ) )
                return; ?>

            <?php if ( ! empty( $this->label ) ) : ?>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <?php endif; ?>

            <?php if ( ! empty( $this->description ) ) : ?>
                <span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
            <?php endif; ?>

            <?php $multi_values = ! is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

            <ul>
                <?php foreach ( $this->choices as $value => $label ) : ?>

                    <li>
                        <label>
                            <input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> />
                            <?php echo esc_html( $label ); ?>
                        </label>
                    </li>

                <?php endforeach; ?>
            </ul>

            <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
        <?php }
    }

    class iRepair_Checkbox_Multiple_Product_Categories_Control extends WP_Customize_Control {

        public $type = 'product-categories-checkbox-multiple';

        public function render_content() {

            ?>

            <?php if ( ! empty( $this->label ) ) : ?>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
            <?php endif; ?>

            <?php if ( ! empty( $this->description ) ) : ?>
                <span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
            <?php endif; ?>

            <?php $product_categories_multi_values = ! is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

            <ul class="pix-selected-categories-list">
            <?php
            $woo_args = array(
                 'taxonomy' => 'product_cat',
                 'orderby' => 'menu_order',
                 'parent' => 0,
                 'hide_empty' => false
            );

            $woo_categories = get_categories( $woo_args );
            foreach ( $woo_categories as $cat ) { ?>
                <li>
                    <label>
                        <input type="checkbox" value="<?php echo esc_attr( $cat->slug ); ?>" <?php checked( in_array( $cat->slug, $product_categories_multi_values ) ); ?> />
                        <?php echo esc_html( $cat->name ); ?>
                    </label>
                    <?php
                    $woo_sub_args = array(
                         'taxonomy' => 'product_cat',
                         'orderby' => 'menu_order',
                         'parent' => $cat->term_id,
                         'hide_empty' => false
                    );
                    $woo_subcategories = get_categories( $woo_sub_args );
                    ?>
                    <?php if ( $woo_subcategories ) { ?>
                        <ul>
                            <?php foreach ( $woo_subcategories as $subcat ) { ?>
                                <li>
                                    <label>
                                        <input type="checkbox" value="<?php echo esc_attr( $subcat->slug ); ?>" <?php checked( in_array( $subcat->slug, $product_categories_multi_values ) ); ?> />
                                        <?php echo esc_html( $subcat->name ); ?>
                                    </label>
                                    <?php
                                    $woo_sub_sub_args = array(
                                         'taxonomy' => 'product_cat',
                                         'orderby' => 'menu_order',
                                         'parent' => $subcat->term_id,
                                         'hide_empty' => false
                                    );
                                    $woo_sub_subcategories = get_categories( $woo_sub_sub_args );
                                    ?>
                                    <?php if ( $woo_sub_subcategories ) { ?>
                                        <ul>
                                            <?php foreach ( $woo_sub_subcategories as $sub_subcat ) { ?>
                                            <li>
                                                <label>
                                                    <input type="checkbox" value="<?php echo esc_attr( $sub_subcat->slug ); ?>" <?php checked( in_array( $sub_subcat->slug, $product_categories_multi_values ) ); ?> />
                                                    <?php echo esc_html( $sub_subcat->name ); ?>
                                                </label>
                                            </li>
                                            <?php } ?>
                                        </ul>
                                    <?php } ?>
                                </li>
                            <?php } ?>
                        </ul>
                    <?php } ?>
                </li>
            <?php
            }
            ?>

            </ul>

            <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $product_categories_multi_values ) ); ?>" />
        <?php }
    }
    
endif;
