<?php

function irepair_customize_layout_tab( $wp_customize, $theme_name ) {

    $layout_arr = array(
        'left-sidebar' => esc_url( get_template_directory_uri() . '/assets/img/customizer/layout-left-sidebar.svg' ),
        'without-sidebar' => esc_url( get_template_directory_uri() . '/assets/img/customizer/layout-without-sidebar.svg' ),
        'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/img/customizer/layout-right-sidebar.svg' ),
    );

    global $wp_registered_sidebars;
    foreach( $wp_registered_sidebars as $key => $val ) {
        if ( $val['id'] !== 'product-filter' ) {
            $irepair_sidebars[$val['id']] = $val['name'];
        }
    }

    $wp_customize->add_panel(
        'irepair_layout_panel',
        array(
            'title' => esc_html__( 'Layout', 'irepair' ),
            'priority' => 35
        )
    );

    $wp_customize->add_section(
        'irepair_page_layout_settings',
        array(
            'title' => esc_html__( 'Page', 'irepair' ),
            'panel' => 'irepair_layout_panel',
            'priority' => 10
        )
    );

    $wp_customize->add_setting(
        'irepair_page_layout' ,
        array(
            'default' => 'without-sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new iRepair_Radio_Image_Control(
            $wp_customize,
            'irepair_page_layout',
            array(
               'label' => esc_html__( 'Page Layout', 'irepair' ),
               'section' => 'irepair_page_layout_settings',
               'choices' => $layout_arr,
               'priority' => 10
            )
       )
    );

    $wp_customize->add_setting(
        'irepair_page_sidebar',
        array(
            'default' => 'page-sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        'irepair_page_sidebar',
        array(
            'label' => esc_html__( 'Page Sidebar', 'irepair' ),
            'section' => 'irepair_page_layout_settings',
            'type' => 'select',
            'choices' => $irepair_sidebars,
            'priority' => 20
        )
    );

    // blog
    $wp_customize->add_section(
        'irepair_blog_layout_settings',
        array(
            'title' => esc_html__( 'Blog', 'irepair' ),
            'panel' => 'irepair_layout_panel',
            'priority' => 20
        )
    );

    $wp_customize->add_setting(
        'irepair_archive_post_layout' ,
        array(
            'default' => 'right-sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new iRepair_Radio_Image_Control(
            $wp_customize,
            'irepair_archive_post_layout',
            array(
               'label' => esc_html__( 'Blog Layout', 'irepair' ),
               'section' => 'irepair_blog_layout_settings',
               'choices' => $layout_arr,
               'priority' => 10
            )
       )
    );

    $wp_customize->add_setting(
        'irepair_archive_post_sidebar',
        array(
            'default' => 'sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        'irepair_archive_post_sidebar',
        array(
            'label' => esc_html__( 'Blog Sidebar', 'irepair' ),
            'section' => 'irepair_blog_layout_settings',
            'description' => esc_html__( 'Select sidebar type for blog pages (not for static page) - all posts, arhive, category, etc.', 'irepair' ),
            'type' => 'select',
            'choices' => $irepair_sidebars,
            'priority' => 20
        )
    );

    $wp_customize->add_setting(
        'irepair_post_layout' ,
        array(
            'default' => 'right-sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        new iRepair_Radio_Image_Control(
            $wp_customize,
            'irepair_post_layout',
            array(
               'label' => esc_html__( 'Post Layout', 'irepair' ),
               'section' => 'irepair_blog_layout_settings',
               'choices' => $layout_arr,
               'priority' => 30
            )
       )
    );

    $wp_customize->add_setting(
        'irepair_post_sidebar',
        array(
            'default' => 'sidebar',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        'irepair_post_sidebar',
        array(
            'label' => esc_html__( 'Post Sidebar', 'irepair' ),
            'section' => 'irepair_blog_layout_settings',
            'description' => esc_html__( 'Select sidebar type for Single Post.', 'irepair' ),
            'type' => 'select',
            'choices' => $irepair_sidebars,
            'priority' => 40
        )
    );

    // portfolio
    if ( irepair_use_portfolio() ) :

        $wp_customize->add_section(
            'irepair_portfolio_layout_settings',
            array(
                'title' => esc_html__( 'Portfolio', 'irepair' ),
                'panel' => 'irepair_layout_panel',
                'priority' => 30
            )
        );

        $wp_customize->add_setting(
        'irepair_archive_portfolio_layout' ,
            array(
                'default' => 'right-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            new iRepair_Radio_Image_Control(
                $wp_customize,
                'irepair_archive_portfolio_layout',
                array(
                   'label' => esc_html__( 'Portfolio Layout', 'irepair' ),
                   'section' => 'irepair_portfolio_layout_settings',
                   'choices' => $layout_arr,
                   'priority' => 10
                )
           )
        );

        $wp_customize->add_setting(
        'irepair_archive_portfolio_sidebar',
            array(
                'default' => 'portfolio-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            'irepair_archive_portfolio_sidebar',
            array(
                'label' => esc_html__( 'Portfolio Sidebar', 'irepair' ),
                'section' => 'irepair_portfolio_layout_settings',
                'description' => esc_html__( 'Select sidebar type for all portfolio works, arhive, category, etc.', 'irepair' ),
                'type' => 'select',
                'choices' => $irepair_sidebars,
                'priority' => 20
            )
        );

    endif;

    // service
    if ( irepair_use_service() ) :

        $wp_customize->add_section(
            'irepair_service_layout_settings',
            array(
                'title' => esc_html__( 'Services', 'irepair' ),
                'panel' => 'irepair_layout_panel',
                'priority' => 40
            )
        );

        $wp_customize->add_setting(
        'irepair_archive_service_layout' ,
            array(
                'default' => 'right-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            new iRepair_Radio_Image_Control(
                $wp_customize,
                'irepair_archive_service_layout',
                array(
                   'label' => esc_html__( 'Services Layout', 'irepair' ),
                   'section' => 'irepair_service_layout_settings',
                   'choices' => $layout_arr,
                   'priority' => 10
                )
           )
        );

        $wp_customize->add_setting(
        'irepair_archive_service_sidebar',
            array(
                'default' => 'service-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            'irepair_archive_service_sidebar',
            array(
                'label' => esc_html__( 'Services Sidebar', 'irepair' ),
                'section' => 'irepair_service_layout_settings',
                'description' => esc_html__( 'Select sidebar type for all services, arhive, category, etc.', 'irepair' ),
                'type' => 'select',
                'choices' => $irepair_sidebars,
                'priority' => 20
            )
        );

        $wp_customize->add_setting(
        'irepair_service_layout',
            array(
                'default' => 'right-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            new iRepair_Radio_Image_Control(
                $wp_customize,
                'irepair_service_layout',
                array(
                   'label' => esc_html__( 'Single Service Layout', 'irepair' ),
                   'section' => 'irepair_service_layout_settings',
                   'choices' => $layout_arr,
                   'priority' => 30
                )
           )
        );

        $wp_customize->add_setting(
        'irepair_service_sidebar',
            array(
                'default' => 'service-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            'irepair_service_sidebar',
            array(
                'label' => esc_html__( 'Single Service Sidebar', 'irepair' ),
                'section' => 'irepair_service_layout_settings',
                'type' => 'select',
                'choices' => $irepair_sidebars,
                'priority' => 40
            )
        );

    endif;

    // woo
    if ( irepair_use_woo() ) :

        $wp_customize->add_section(
            'irepair_product_layout_settings',
            array(
                'title' => esc_html__( 'Shop', 'irepair' ),
                'panel' => 'irepair_layout_panel',
                'priority' => 50
            )
        );

        $wp_customize->add_setting(
        'irepair_archive_product_layout' ,
            array(
                'default' => 'left-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            new iRepair_Radio_Image_Control(
                $wp_customize,
                'irepair_archive_product_layout',
                array(
                   'label' => esc_html__( 'Products Layout', 'irepair' ),
                   'section' => 'irepair_product_layout_settings',
                   'choices' => $layout_arr,
                   'priority' => 10
                )
           )
        );

        $wp_customize->add_setting(
        'irepair_archive_product_sidebar',
            array(
                'default' => 'product-sidebar',
                'transport' => 'refresh',
                'sanitize_callback' => 'irepair_sanitize_select'
            )
        );

        $wp_customize->add_control(
            'irepair_archive_product_sidebar',
            array(
                'label'    => esc_html__( 'Products Sidebar', 'irepair' ),
                'section'  => 'irepair_product_layout_settings',
                'description' => esc_html__( 'Select sidebar type for all products, arhive, category, etc.', 'irepair' ),
                'type'     => 'select',
                'choices'  => $irepair_sidebars,
                'priority' => 20
            )
        );

    endif;

}
