<?php

function irepair_customize_portfolio_tab( $wp_customize, $theme_name ) {

    $wp_customize->add_panel(
        'irepair_portfolio_panel',
        array(
            'title' => esc_html__( 'Portfolio', 'irepair' ),
            'priority' => 70
        )
    );

    $wp_customize->add_section(
        'irepair_portfolio_single_settings',
        array(
            'title' => esc_html__( 'Single Project', 'irepair' ),
            'panel' => 'irepair_portfolio_panel',
            'priority' => 20
        )
    );

    $wp_customize->add_setting(
        'irepair_use_portfolio_related',
        array(
            'default' => true,
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_checkbox'
        )
    );

    $wp_customize->add_control(
        'irepair_use_portfolio_related',
        array(
            'label'    => esc_html__( 'Show Related projects block', 'irepair' ),
            'section'  => 'irepair_portfolio_single_settings',
            'type'     => 'checkbox',
            'priority' => 10

        )
    );

    $wp_customize->add_section(
        'irepair_portfolio_archive_settings',
        array(
            'title' => esc_html__( 'Archive Projects', 'irepair' ),
            'panel' => 'irepair_portfolio_panel',
            'priority' => 30
        )
    );

    $wp_customize->add_setting(
        'irepair_portfolio_archive_image_proportions',
        array(
            'default' => 'square',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        'irepair_portfolio_archive_image_proportions',
        array(
             'label' => esc_html__( 'Image proportions', 'irepair' ),
             'description' => esc_html__( 'The width of the loaded portfolio preview must be at least the base width of the image (see Appearance->Customize->Portfolio->Image Size)', 'irepair' ),
             'section' => 'irepair_portfolio_archive_settings',
             'type' => 'select',
             'choices' => array(
                 'square' => esc_html__( 'Square', 'irepair' ),
                 'landscape' => esc_html__( 'Landscape', 'irepair' ),
                 'portrait' => esc_html__( 'Portrait', 'irepair' ),
                 'original' => esc_html__( 'Original', 'irepair' ),
             ),
             'priority' => 10,
        )
    );

    $wp_customize->add_setting(
        'irepair_portfolio_archive_cols',
        array(
            'default' => '3',
            'transport' => 'refresh',
            'sanitize_callback' => 'irepair_sanitize_select'
        )
    );

    $wp_customize->add_control(
        'irepair_portfolio_archive_cols',
        array(
             'label' => esc_html__( 'Projects per row', 'irepair' ),
             'description' => esc_html__( 'How many projects should be shown per row?', 'irepair' ),
             'section' => 'irepair_portfolio_archive_settings',
             'type' => 'select',
             'choices' => array(
                 '2' => esc_html__( '2 columns', 'irepair' ),
                 '3' => esc_html__( '3 columns', 'irepair' ),
                 '4' => esc_html__( '4 columns', 'irepair' ),
             ),
             'priority' => 20,
        )
    );

    $wp_customize->add_setting(
        'irepair_portfolio_archive_per_page',
        array(
            'default' => '',
            'transport' => 'refresh',
            'sanitize_callback' => 'absint'
        )
    );

    $wp_customize->add_control(
        'irepair_portfolio_archive_per_page',
        array(
             'label' => esc_html__( 'Items per page', 'irepair' ),
             'description' => esc_html__( 'Number of items to show per page. Input "0" or leave empty to show all posts.', 'irepair' ),
             'section' => 'irepair_portfolio_archive_settings',
             'type' => 'number',
             'input_attrs' => array(
                'min'  => 0,
                'max'  => '',
                'step' => 1,
            ),
             'priority' => 30,
        )
    );

    $wp_customize->add_section(
        'irepair_image_size_settings',
        array(
            'title' => esc_html__( 'Image size', 'irepair' ),
            'panel' => 'irepair_portfolio_panel',
            'priority' => 40
        )
    );

    $wp_customize->add_setting(
        'irepair_image_base_size',
        array(
            'default' => '800',
            'transport' => 'refresh',
            'sanitize_callback' => 'absint'
        )
    );

    $wp_customize->add_control(
        'irepair_image_base_size',
        array(
            'label' => esc_html__( 'Image Base Width', 'irepair' ),
            'description' => esc_html__( 'Based on this size, Portrait, Landscape, Square thumbnails proportions of the image are created. After the change, need to Regenerate Thumbnails', 'irepair' ),
            'section' => 'irepair_image_size_settings',
            'type' => 'number',
            'priority' => 10

        )
    );

    $wp_customize->add_setting(
        'irepair_image_landscape_ratio',
        array(
            'default' => '1.6',
            'transport' => 'refresh',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'irepair_image_landscape_ratio',
        array(
            'label' => esc_html__( 'Image Landscape Ratio', 'irepair' ),
            'description' => esc_html__( '[Ratio]:1 thumbnails proportions of the image are created. After the change, need to Regenerate Thumbnails', 'irepair' ),
            'section' => 'irepair_image_size_settings',
            'type' => 'text',
            'priority' => 20

        )
    );

    $wp_customize->add_setting(
        'irepair_image_portrait_ratio',
        array(
            'default' => '1.3',
            'transport' => 'refresh',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'irepair_image_portrait_ratio',
        array(
            'label' => esc_html__( 'Image Portrait Ratio', 'irepair' ),
            'description' => esc_html__( '1:[Ratio] thumbnails proportions of the image are created. After the change, need to Regenerate Thumbnails', 'irepair' ),
            'section' => 'irepair_image_size_settings',
            'type' => 'text',
            'priority' => 30

        )
    );

}
