<?php

namespace iRepair_Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Widget_Projects extends Base_Posts {

    public function get_name() {
        return 'irepair-projects';
    }

    public function get_title() {
        return esc_html__( 'Projects', 'irepair' );
    }

    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_keywords() {
        return [ 'projects' ];
    }

    protected function get_post_type() {
        return 'pix-portfolio';
    }

    protected function get_taxonomy() {
        return 'pix-portfolio-category';
    }

    public function get_script_depends() {
        return [
            'irepair-widgets-isotope'
        ];
    }

    protected function _register_controls() {
        $this->add_section_content();
        $this->add_image_size_section();
        parent::_register_controls();
    }

    private function add_section_content() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Content', 'irepair' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__( 'Heading', 'irepair' ),
                'default' => esc_html__( 'Projects', 'irepair' ),
            ]
        );

        $this->add_control(
            'show_filter',
            [
                'type' => Controls_Manager::SWITCHER,
                'label' => esc_html__( 'Show filter', 'irepair' ),
                'default' => 'yes',
                'label_off' => esc_html__( 'Hide', 'irepair' ),
                'label_on' => esc_html__( 'Show', 'irepair' ),
            ]
        );

        $this->add_control(
            'cols',
            [
                'label' => esc_html__( 'Projects per row', 'irepair' ),
                'description' => esc_html__( 'How many projects should be shown per row?', 'irepair' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    '2' => esc_html__( '2 columns', 'irepair' ),
                    '3' => esc_html__( '3 columns', 'irepair' ),
                    '4' => esc_html__( '4 columns', 'irepair' ),
                ),
                'default' => '3',
            ]
        );

        $this->add_control(
            'image_proportions',
            [
                'label' => esc_html__( 'Image proportions', 'irepair' ),
                'description' => esc_html__( 'The width of the loaded portfolio preview must be at least the base width of the image (see Appearance->Customize->Portfolio->Image Size)', 'irepair' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'square' => esc_html__( 'Square', 'irepair' ),
                    'landscape' => esc_html__( 'Landscape', 'irepair' ),
                    'portrait' => esc_html__( 'Portrait', 'irepair' ),
                    'original' => esc_html__( 'Original', 'irepair' ),
                ),
                'default' => 'square',
            ]
        );

        $this->add_control(
            'show_button',
            [
                'type' => Controls_Manager::SWITCHER,
                'label' => esc_html__( 'Show button', 'irepair' ),
                'default' => 'yes',
                'label_off' => esc_html__( 'Hide', 'irepair' ),
                'label_on' => esc_html__( 'Show', 'irepair' ),
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label' => esc_html__( 'Button text', 'irepair' ),
                'default' => esc_html__( 'more projects', 'irepair' ),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'show_button' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__( 'Button Link', 'irepair' ),
                'description' => esc_html__( 'Leave empty to use all projects link', 'irepair' ),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__( 'https://your-link.com', 'irepair' ),
                'condition' => [
                    'show_button' => 'yes',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function add_image_size_section() {
        $this->start_controls_section(
            'image_size_section',
            [
                'label' => esc_html__( 'Image Size', 'irepair' ),
            ]
        );

        $this->add_control(
            'image_size_default',
            [
                'label'        => esc_html__( 'Use Default Thumbnail Size', 'irepair' ),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => '1',
                'return_value' => '1',
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'image_size',
                'default'   => 'full',
                'condition' => [
                    'image_size_default!' => '1',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function print_items( array $settings = null ) {
        if ( null === $settings ) {
            $settings = $this->get_settings_for_display();
        }
        ?>

        <div class="widget-projects-isotope">
            <div class="projects__top">
                <?php if ( ! empty( $title = $settings['title'] ) ) : ?>
                <div class="projects__title">
                    <h2><?php echo esc_html( $title ); ?></h2>
                </div>
                <?php endif; ?>
                <?php if ( ! empty( $settings['show_filter'] ) && 'yes' === $settings['show_filter'] ) : ?>
                    <?php
                    $terms = [];
                    $attributes = [
                        'taxonomy' => 'pix-portfolio-category',
                    ];
                    $term_ids = [];
                    if ( ! empty( $term_slugs = $settings['include_term_slugs'] ) ) :
                        foreach( $term_slugs as $slug ) {
                            $term = get_term_by( 'slug', $slug, 'pix-portfolio-category' );
                            if ( isset( $term->term_id ) ) {
                                $term_ids[] = $term->term_id;
                            }
                        }
                        $attributes['include'] = $term_ids;
                    endif;
                    $terms = get_terms( $attributes );
                    ?>
                    <ul class="projects__filter projects__filter-isotope">
                        <li class="active"><a href="#" data-filter="*"><?php echo esc_html__( 'All', 'irepair' ); ?></a></li>
                        <?php
                        foreach ( $terms as $term ) :
                            $term_name = $term->name;
                            $term_slug = $term->slug;
                            echo '<li><a data-filter=".' . esc_attr( $term_slug ) . '" href="#">' . esc_attr( $term_name ) . '</a></li>';
                        endforeach;
                        ?>
                    </ul>
                <?php endif; ?>
            </div>
            <?php
            $this->query_posts();

            $posts_query = $this->get_query();
            ?>
            <?php if ( $posts_query->have_posts() ) : ?>
                <?php
                $irepair_add_class = '';
                $cols = $settings['cols'];
                if ( '2' === $cols ) {
                    $irepair_add_class = 'row-cols-lg-2';
                } elseif ( '3' === $cols ) {
                    $irepair_add_class = 'row-cols-lg-2 row-cols-xl-3';
                } elseif ( '4' === $cols ) {
                    $irepair_add_class = 'row-cols-md-2 row-cols-lg-3 row-cols-xy-4';
                }
                ?>
                <div class="projects__container row mb-n30 row-cols-1 <?php echo esc_attr( $irepair_add_class ); ?>">
                    <?php while ( $posts_query->have_posts() ) : $posts_query->the_post(); ?>
                        <?php $this->print_item( $settings ); ?>
                    <?php endwhile; ?>
                </div>
                <?php if ( ! empty( $settings['show_button'] ) && 'yes' === $settings['show_button'] && ! empty( $btn_text = $settings['btn_text'] )  ) : ?>
                    <?php
                    $irepair_all_projects_id = irepair_get_option( 'archive_portfolio_page', 'default' );
                    ?>
                    <div class="projects__btn">
                        <?php if ( ! empty( $btn_link = $settings['btn_link']['url'] ) ) : ?>
                            <?php
                            $target = $settings['btn_link']['is_external'] ? ' target="_blank"' : '';
                            $nofollow = $settings['btn_link']['nofollow'] ? ' rel="nofollow"' : '';
                            ?>
                            <a class="btn btn-black" href="<?php echo esc_url( $btn_link ); ?>"<?php echo wp_kses( $target . $nofollow, 'strip' ); ?>><?php echo esc_html( $btn_text ); ?><i class="pix-icon-caret-right"></i></a>
                            <?php else : ?>
                                <?php if ( $irepair_all_projects_id && $irepair_all_projects_id != 'default' ) :
                                    if ( function_exists( 'icl_object_id' ) ) :
                                        $irepair_all_projects_id = icl_object_id( $irepair_all_projects_id, 'page', true );
                                    endif; ?>
                                    <a class="btn btn-black" href="<?php echo esc_url( get_page_link( $irepair_all_projects_id ) ); ?>"><?php echo esc_html( $btn_text ); ?><i class="pix-icon-caret-right"></i></a>
                                <?php else : ?>
                                    <a class="btn btn-black" href="<?php echo get_post_type_archive_link( 'pix-portfolio' ); ?>"><?php echo esc_html( $btn_text ); ?><i class="pix-icon-caret-right"></i></a>
                                <?php endif; ?>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        </div>
        <?php wp_reset_postdata(); ?>
        <?php
    }

    protected function print_item( array $settings ) {
        set_query_var( 'settings', $settings );

        get_template_part( 'template-parts/portfolio/content' );
    }

}
