<?php

function irepair_breadcrumbs() {

    global $wp_query, $post;

    $front_page_id = get_option( 'page_on_front' );
    $posts_page_id = get_option( 'page_for_posts' );
    $show_on_front = get_option( 'show_on_front' );

    $text['home'] = esc_html__( 'Home', 'irepair' );
    $home_link = esc_url( home_url('/') );

    $out = '';

    $show_current = irepair_get_option( 'show_breadcrumbs_current', true );

    $container_start = '<ol class="breadcrumb justify-content-center">';
    $container_end = '</ol>';
    $item_before = '<li class="breadcrumb-item">';
    $item_after = '</li>';
    $link_attr = '';
    $link_in_before = '';
    $link_in_after = '';

    $link = $item_before . '<a href="%1$s"' . $link_attr . '>' . $link_in_before . '%2$s' . $link_in_after . '</a>' . $item_after;
    $current = ( $show_current ) ? $item_before . '<span>%1$s</span>' . $item_after : '';

    if ( irepair_use_woo() ) {
        $products_archive_link_title = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';

        if ( ! $products_archive_link_title ) {
            $product_post_type = get_post_type_object( 'product' );
            $products_archive_link_title = $product_post_type->labels->name;
        }
    }

    if ( irepair_use_portfolio() ) {
        $irepair_all_projects_id = irepair_get_option( 'archive_portfolio_page', 'default' );
        $portfolio_archive_link_title = ( $irepair_all_projects_id && $irepair_all_projects_id != 'default' ) ? get_the_title( $irepair_all_projects_id ) : '';

        if ( ! $portfolio_archive_link_title ) {
            $portfolio_post_type = get_post_type_object( 'pix-portfolio' );
            $portfolio_archive_link_title = irepair_get_option( 'header_archive_portfolio_title', esc_html__( 'Portfolio', 'irepair' ) );
        }

        $portfolio_archive_url = ( $irepair_all_projects_id && $irepair_all_projects_id != 'default' ) ? get_permalink( $irepair_all_projects_id ) : get_post_type_archive_link( 'pix-portfolio' );
    }

    if ( 'posts' === $show_on_front ) {
        $posts_archive_link_title = irepair_get_option( 'header_home_title', esc_html__( 'Blog', 'irepair' ) );
    }
    elseif ( 'page' === $show_on_front ) {
        if ( $posts_page_id ) {
            $posts_page = get_post( $posts_page_id );
            $posts_archive_link_title = $posts_page->post_title;
        }
    }

    $out .= $container_start;

    if ( ! ( ( is_home()  && 'posts' === $show_on_front ) || is_front_page() ) ) {
        $out .= sprintf( $link, $home_link, $text['home'] );
    }
    if ( is_home() ) {
        if ( 'posts' === $show_on_front ) {
            $out .= '';
        } elseif ( 'page' === $show_on_front ) {
            if ( $posts_page_id ) {
                $posts_page = get_post( $posts_page_id );
                $out .= sprintf( $current, $posts_page->post_title );
            }
        }
    } elseif ( is_front_page() ) {
        $out .= '';
    } elseif ( irepair_use_woo() && function_exists( 'is_shop' ) && is_shop() ) {
        $out .= sprintf( $current, $products_archive_link_title );
    } elseif ( irepair_use_portfolio() && is_post_type_archive( 'pix-portfolio' ) ) {
        $out .= sprintf( $current, $portfolio_archive_link_title );
    } elseif ( is_404() ) {
        $out .= sprintf( $current, esc_html__( 'Error 404', 'irepair' ) );
    } elseif ( is_search() ) {
        $out .= sprintf( $current,  irepair_get_option( 'header_search_title', esc_html__( 'Search results for:', 'irepair' ) ) . ' ' . '"' . get_search_query() . '"' );
    } elseif ( is_attachment() ) {
            if ( $post->post_parent ) {
                if ( $parent_post = get_post( $post->post_parent ) ) {
                    $out .= sprintf( $link, get_the_permalink( $parent_post ), $parent_post->post_title );
                    $out .= sprintf( $current, get_the_title() );
                }
            }
    } elseif ( is_singular() ) {
        $post_type = get_post_type_object( $post->post_type );
        if ( $post_type ) {
            if ( 'post' === $post_type->name ) {
                $out .= sprintf( $link, get_post_type_archive_link( $post_type->name ), $posts_archive_link_title );
            } elseif ( irepair_use_woo() && 'product' === $post_type->name ) {
                $out .= sprintf( $link, get_post_type_archive_link( $post_type->name ), $products_archive_link_title );
            } elseif ( 'pix-portfolio' === $post_type->name ) {
                $out .= sprintf( $link, $portfolio_archive_url, $portfolio_archive_link_title );
            } else {

                if ( $post_type && $post_type->has_archive ) {
                    $out .= sprintf( $link, get_post_type_archive_link( $post_type->name ), $post_type->label );
                }

                if ( is_post_type_hierarchical( $post_type->name ) ) {
                    $parent_ids = array_reverse( get_post_ancestors( $post ) );
                    if ( count( $parent_ids ) ) {
                        $parent_posts = get_posts( array(
                                'post_type' => $post_type->name,
                                'include' => implode( ',', $parent_ids )
                            )
                        );
                        foreach ( $parent_ids as $parent_id ) {
                            foreach ( $parent_posts as $parent_post ) {
                                if ( $parent_id == $parent_post->ID ) {
                                    $out .= sprintf( $link, get_permalink( $parent_post->ID ), $parent_post->post_title );
                                }
                            }
                        }
                    }
                }
            }
            $out .= sprintf( $current, $post->post_title );
        }
    } elseif ( is_tax() ) {

        if ( irepair_use_woo() && function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) {
            $out .= sprintf( $link, get_post_type_archive_link( 'product' ), $products_archive_link_title );
        }

        if ( irepair_use_portfolio() && is_tax( 'pix-portfolio-category' ) ) {
            $out .= sprintf( $link, $portfolio_archive_url, $portfolio_archive_link_title );
        }

        $taxonomy = get_query_var( 'taxonomy' );
        $term = $wp_query->queried_object;
        if ( is_taxonomy_hierarchical( $taxonomy ) && $term->parent != 0 ) {
            $parents = array_reverse( get_ancestors( $term->term_id, $taxonomy ) );
            foreach ( $parents as $parent_id ) {
                $parent = get_term( $parent_id, $taxonomy );
                if ( ! is_wp_error( $parent ) && ! empty( $parent->slug ) ) {
                    $out .= sprintf( $link, get_term_link( $parent, $term->slug ), $parent->name );
                }
            }
        }
        $out .= sprintf( $current, $term->name );
    } elseif ( is_category() ) {
        global $cat;

        $out .= sprintf( $link, get_post_type_archive_link( 'post' ), $posts_archive_link_title );

        $category = get_category( $cat );
        if ( $category->parent != 0 ) {
            $parents = array_reverse( get_ancestors( $category->term_id, 'category' ) );
            foreach ( $parents as $parent_id ) {
                $parent = get_category( $parent_id );
                $out .= sprintf( $link, get_category_link( $parent->term_id ), $parent->name );
            }
        }
        $out .= sprintf( $current, $category->name );
    } elseif ( is_tag() ) {
        $out .= sprintf( $link, get_post_type_archive_link( 'post' ), $posts_archive_link_title );

        global $tag_id;
        $tag = get_tag( $tag_id );
        $out .= sprintf( $current, $tag->name );
    } elseif ( is_author() ) {
        $out .= sprintf( $current, get_the_author_meta( 'display_name', get_query_var( 'author' ) ) );
    } elseif ( is_day() ) {
        $out .= sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) );
        $out .= sprintf( $link, get_month_link( get_the_time('Y'), get_the_time('m') ), get_the_time( 'F' ) );
        $out .= sprintf( $current, get_the_time( 'd' ) );

    } elseif ( is_month() ) {
        $out .= sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ) );
        $out .= sprintf( $current, get_the_time( 'F' ) );

    } elseif ( is_year() ) {
        $out .= sprintf( $current, get_the_time( 'Y' ) );
    } elseif ( is_post_type_archive() ) {
        $post_type = get_post_type_object( get_query_var( 'post_type' ) );
        $out .= sprintf( $current, $post_type->label );
    }

    $out .= $container_end;

    echo wp_kses( $out, 'irepair-default' );

}
