<?php

if ( ! function_exists( 'irepair_browser_body_class' ) ) :
    function irepair_browser_body_class( $classes = '' ) {

        if ( ( 'usemain' === irepair_get_option( 'loader', 'useall' ) && is_front_page() ) || 'useall' === irepair_get_option( 'loader', 'useall' ) ) {
            $classes[] = 'loading';
        }

        $under_header_section_id = irepair_get_option( 'shop_under_header_block', 'default' );

        if ( function_exists( 'is_shop' ) && is_shop() && irepair_use_section() && $under_header_section_id && $under_header_section_id != 'default' ) {
            //$classes[] = 'irepair-overbox';
        } elseif ( is_page_template( 'templates/home-template.php' ) ) {
            $classes[] = 'irepair-home';
        } elseif ( is_page_template()
            || ( function_exists( 'is_shop' ) && is_shop() )
            || ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() )
            || is_post_type_archive( 'pix-portfolio' )
            || is_tax( 'pix-portfolio-category' )
        ) {
            $classes[] = 'irepair-not-overbox';
        } else {
            //$classes[] = 'irepair-overbox';
        }

        if ( irepair_use_woo() ) {
            $classes[] = 'woocommerce';
        }

        if ( wp_is_mobile() ) {
            $classes[] = 'irepair-is-mobile';
        }

        return $classes;
    }
endif;
add_filter( 'body_class', 'irepair_browser_body_class' );

function irepair_get_post_meta( $slug, $default = false ) {

    if ( is_home() && 'page' === get_option( 'show_on_front' ) ) {
        $post_id = get_option( 'page_for_posts' );
    } elseif ( function_exists( 'is_shop' ) && is_shop() ) {
        $post_id = wc_get_page_id( 'shop' );
    } else {
        $post_id = get_the_ID();
    }

    $post_metas = get_post_meta( $post_id );

    $slug = 'irepair_' . $slug;

    if ( $post_metas != false && isset( $post_metas[ $slug ] ) ) {
        return $post_metas[ $slug ][0];
    }

    return $default;

}

function irepair_get_option( $slug, $default = false ) {

    $theme_slug = get_option( 'stylesheet' );

    if ( $stgs = irepair_get_customize_settings() ) {
        $slug_option_name = 'irepair_' . $slug;

        if ( isset( $stgs->$slug_option_name ) )
            return $stgs->$slug_option_name;
    }

    $slug = 'irepair_' . $slug;

    $theme_options = get_option( 'theme_mods_' . $theme_slug );

    if ( isset( $theme_options[ $slug ] ) ) {
        return $theme_options[ $slug ];
    }

    return $default;

}

function irepair_get_customize_settings() {

    if ( isset( $_POST['wp_customize'] ) && 'on' === $_POST['wp_customize'] ) {
        $settings = json_decode( stripslashes( $_POST['customized'] ) );
        return $settings;
    } else {
        return false;
    }

}

if ( ! function_exists( 'irepair_add_inline_css' ) ) :
    function irepair_add_inline_css() {

        if ( ( 'usemain' === irepair_get_option( 'loader', 'useall' ) && is_front_page() ) || 'useall' === irepair_get_option( 'loader', 'useall' ) ) {
            echo "<style>
                .loading {
                    overflow: hidden;
                    background: #141315;
                }
                .loading > .irepair {
                    visibility: hidden;
                    opacity: 0;
                }
                .loading > .preloader {
                    display: block;
                }

                .preloader {
                    display: none;
                    position: fixed;
                    left: 0;
                    right: 0;
                    top: 0;
                    bottom: 0;
                    margin: auto;
                    width: 100px;
                    height: 100px;
                    perspective: 780px;
                    z-index: 100;
                }
                .pix-loading{
                    width: 50px;
                    height: 50px;
                    position: absolute;
                    top: 50%;
                    left: 50%;
                    -webkit-transform: translate(-50%, -50%);
                    -ms-transform: translate(-50%, -50%);
                    transform: translate(-50%, -50%)
                }
                .pix-loading.m{
                    width: 32px;
                    height: 32px;
                }
                .pix-loading:before,
                .pix-loading:after{
                    content: '';
                    display: block;
                    width: 100%;
                    height: 100%;
                    border-radius: 50%;
                    background-color: var(--accent);
                    opacity: 0.75;
                    position: absolute;
                    top: 0;
                    left: 0;
                    -webkit-animation: pix-loading 2.0s infinite ease-in-out;
                    animation: pix-loading 2.0s infinite ease-in-out
                }
                .pix-loading.m:before,
                .pix-loading.m:after{
                    width: 50%;
                    height: 50%;
                    top: calc(50% - 7px);
                    left: calc(50% - 7px);
                }
                .pix-loading:after{
                    -webkit-animation-delay: -1.0s;
                    animation-delay: -1.0s
                }
                @-webkit-keyframes pix-loading {
                    0%,
                    100% {
                        transform: scale(0);
                        -webkit-transform: scale(0)
                    }
                    50% {
                        transform: scale(1);
                        -webkit-transform: scale(1)
                    }
                }
                @keyframes pix-loading {
                    0%,
                    100% {
                        transform: scale(0);
                        -webkit-transform: scale(0)
                    }
                    50% {
                        transform: scale(1);
                        -webkit-transform: scale(1)
                    }
                }
            </style>";
        }
    }
endif;
add_action( 'wp_head', 'irepair_add_inline_css', 1 );

if ( ! function_exists( 'irepair_get_post_terms' ) ) :
    function irepair_get_post_terms( $args = array() ) {

        $html = '';

        $defaults = array(
            'post_id'    => get_the_ID(),
            'taxonomy'   => 'category',
            'text'       => '%s',
            'before'     => '',
            'after'      => '',
            'items_wrap' => '%s',
            'sep'        => ', ',
        );

        $args = wp_parse_args( $args, $defaults );

        $terms = get_the_term_list( $args['post_id'], $args['taxonomy'], '', $args['sep'], '' );

        if ( !empty( $terms ) ) {
            $html .= $args['before'];
            $html .= sprintf( $args['items_wrap'], sprintf( $args['text'], $terms ) );
            $html .= $args['after'];
        }

        return $html;
    }
endif;

if ( irepair_use_section() ) {
    function irepair_get_section_content( $id ) {
        echo Pix_Section::get_section_content( $id );
    }
}

function irepair_pre_get_posts( $query ) {
    if ( is_admin()  )
        return;

    if ( irepair_use_portfolio() ) {

        $per_page = irepair_get_option( 'portfolio_archive_per_page', '' );

        if ( is_numeric( $per_page ) && $per_page > 0 ) {
            $per_page = absint( $per_page );
        } else {
            $per_page = -1;
        }

        if ( is_post_type_archive( 'pix-portfolio' ) && $query->is_main_query() ) {
            // Display n posts for a custom post type 'pix-portfolio' on page portfolio archive
            $query->set( 'posts_per_page', $per_page );
            return;
        }

        if ( is_tax( 'pix-portfolio-category' ) && $query->is_main_query() ) {
            // Display n posts for a custom post type 'pix-portfolio' on page portfolio category taxonomy
            $query->set( 'posts_per_page', $per_page );
            $post_type = get_query_var('post_type');
            if ( ! $post_type ) {
                $post_type = array( 'post', 'pix-portfolio' );
                $query->set( 'post_type', $post_type );
            }
            return;
        }

    }

    if ( irepair_use_service() ) {

        $per_page = irepair_get_option( 'service_posts_per_page', 12 );
        if ( is_numeric( $per_page ) && $per_page != '0' ) {
            $per_page = absint( $per_page );
        } else {
            $per_page = -1;
        }


        if ( is_post_type_archive( 'pix-service' ) && $query->is_main_query() ) {
            // Display n posts for a custom post type 'pix-service' on page service archive
            $query->set( 'posts_per_page', $per_page );
            return;
        }

        if ( is_tax( 'pix-service-category' ) && $query->is_main_query() ) {
            // Display n posts for a custom post type 'pix-service' on page service category taxonomy
            $query->set( 'posts_per_page', $per_page );
            $post_type = get_query_var('post_type');
            if ( ! $post_type ) {
                $post_type = array( 'post', 'pix-service' );
                $query->set( 'post_type', $post_type );
            }
            return;
        }

    }

}
if ( irepair_use_service() || irepair_use_portfolio() ) {
    add_action( 'pre_get_posts', 'irepair_pre_get_posts' );
}

add_action( 'wp_ajax_add_projects', 'irepair_add_projects' );
add_action( 'wp_ajax_nopriv_add_projects', 'irepair_add_projects' );
function irepair_add_projects() {
    $currentpage = ( ! empty( $_POST['current'] ) ) ? esc_attr( $_POST['current'] ) : false;
    $maxpage = ( ! empty( $_POST['max'] ) ) ? esc_attr( $_POST['max'] ) : false;
    $currenttermid = ( ! empty( $_POST['termid'] ) ) ? esc_attr( $_POST['termid'] ) : false;
    $currenttaxonomy = ( ! empty( $_POST['taxonomy'] ) ) ? esc_attr( $_POST['taxonomy'] ) : false;

    if ( ! $currentpage || ! $maxpage ) {
        die();
    }

    $per_page = irepair_get_option( 'portfolio_archive_per_page', '' );

    if ( is_numeric( $per_page ) && $per_page > 0 ) {
        $per_page = absint( $per_page );
    } else {
        $per_page = -1;
    }

    if ( $currenttermid && $currenttaxonomy ) :

    $args = array(
                'post_type' => 'pix-portfolio',
                'post_status' => 'publish',
                'paged' => $currentpage,
                'posts_per_page' => $per_page,
                'tax_query' => array(
                    array(
                        'taxonomy' => $currenttaxonomy,
                        'field'    => 'id',
                        'terms'    => $currenttermid
                    )
                )
            );

    else :

        $args = array(
                'post_type' => 'pix-portfolio',
                'post_status' => 'publish',
                'paged' => $currentpage,
                'posts_per_page' => $per_page,
            );

    endif;

    $portfolio_query = new WP_Query( $args );

    if ( $portfolio_query->have_posts() ) :

        while ( $portfolio_query->have_posts() ) :
            $portfolio_query->the_post();

            get_template_part( 'template-parts/portfolio/content' );

        endwhile;

    endif;

    wp_reset_postdata();

    wp_die();
}

function irepair_trim_phone( $phone ) {
    return str_replace( array( ' ', '-', '.', '(', ')', ' . ' ), '', $phone );
}

function pixtheme_hex2rgb($hex) {
    $hex = str_replace("#", "", $hex);

    if(strlen($hex) == 3) {
        $r = hexdec(substr($hex,0,1).substr($hex,0,1));
        $g = hexdec(substr($hex,1,1).substr($hex,1,1));
        $b = hexdec(substr($hex,2,1).substr($hex,2,1));
    } else {
        $r = hexdec(substr($hex,0,2));
        $g = hexdec(substr($hex,2,2));
        $b = hexdec(substr($hex,4,2));
    }
    $rgb = array($r, $g, $b);
    //return $rgb; // returns an array with the rgb values
    return implode(",", $rgb); // returns the rgb values separated by commas
}

function pixtheme_lighten_darken_color($hex, $amt) {
    
    $hex = str_replace("#", "", $hex, $count);
    $usePound = false;
    
    if ($count > 0) {
        $usePound = true;
    }
    
    if(strlen($hex) == 3) {
        $r = hexdec(substr($hex,0,1).substr($hex,0,1));
        $g = hexdec(substr($hex,1,1).substr($hex,1,1));
        $b = hexdec(substr($hex,2,1).substr($hex,2,1));
    } else {
        $r = hexdec(substr($hex,0,2));
        $g = hexdec(substr($hex,2,2));
        $b = hexdec(substr($hex,4,2));
    }
    
    $r = $r + $amt;
    
    if ($r > 255) {
        $r = 255;
    } elseif($r < 0) {
        $r = 0;
    }
    
    $g = $g + $amt;
    
    if ($g > 255) {
        $g = 255;
    } elseif($g < 0) {
        $g = 0;
    }
    
    $b = $b + $amt;
    
    if ($b > 255) {
        $b = 255;
    } elseif($b < 0) {
        $b = 0;
    }
    
    return esc_attr( ($usePound ? "#" : "") . sprintf("%02X%02X%02X", $r, $g, $b) );
    //return esc_attr( ($usePound ? "#" : "") . dechex(($r<<16)|($g<<8)|$b ) );
    
}

function irepair_get_layout() {

    $class = '';

    if ( is_home() && 'page' === get_option( 'show_on_front' ) ) {
        $post_id = get_option( 'page_for_posts' );
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'archive_post_layout', 'right-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'archive_post_sidebar', 'sidebar' );
    } elseif ( is_tax( 'pix-portfolio-category' ) || is_post_type_archive( 'pix-portfolio' ) ) {
        $layout = irepair_get_option( 'archive_portfolio_layout', 'right-sidebar' );
        $sidebar = irepair_get_option( 'archive_portfolio_sidebar', 'portfolio-sidebar' );
    } elseif ( is_tax( 'pix-service-category' ) || is_post_type_archive( 'pix-service' ) ) {
        $layout = irepair_get_option( 'archive_service_layout', 'right-sidebar' );
        $sidebar = irepair_get_option( 'archive_service_sidebar', 'service-sidebar' );
    } elseif ( is_post_type_archive( 'product' ) || ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) ) {
        $layout = irepair_get_option( 'archive_product_layout', 'left-sidebar' );
        $sidebar = irepair_get_option( 'archive_product_sidebar', 'product-sidebar' );
    } elseif ( is_archive() || ( is_home() && 'posts' === get_option( 'show_on_front' )  ) || is_search() ) {
        $layout = irepair_get_option( 'archive_post_layout', 'right-sidebar' );
        $sidebar = irepair_get_option( 'archive_post_sidebar', 'sidebar' );
    } elseif ( is_page() ) {
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'page_layout', 'without-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'page_sidebar', 'page-sidebar' );
    } elseif ( is_singular( 'post' ) ) {
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'post_layout', 'right-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'post_sidebar', 'sidebar' );
    } elseif ( is_singular( 'pix-portfolio' ) ) {
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'portfolio_layout', 'right-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'portfolio_sidebar', 'portfolio-sidebar' );
    } elseif ( is_singular( 'pix-service' ) ) {
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'service_layout', 'right-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'service_sidebar', 'service-sidebar' );
    } elseif ( is_singular( 'product' ) ) {
        $layout = irepair_get_post_meta( 'page_layout', 'global' ) != 'global' ? irepair_get_post_meta( 'page_layout', 'global' ) : irepair_get_option( 'product_layout', 'right-sidebar' );
        $sidebar = irepair_get_post_meta( 'page_sidebar', 'global') != 'global' ? irepair_get_post_meta( 'page_sidebar', 'global') : irepair_get_option( 'product_sidebar', 'product-sidebar' );
    } else {
        $layout = 'right-sidebar';
        $sidebar = 'sidebar';
    }

    if ( ! is_active_sidebar( $sidebar ) ) {
        if ( 'product-sidebar' === $sidebar && ( ( function_exists( 'is_shop' ) && is_shop() ) || ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) ) ) {
            if ( ! is_active_sidebar( 'product-filter' ) ) {
                $layout = 'without-sidebar';
            }
        } else {
            $layout = 'without-sidebar';
        }
    }

    if ( ( function_exists( 'is_shop' ) && is_shop() ) || ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) ) {
        if ( 'right-sidebar' === $layout ) {
            $class = 'col-xx-9 col-lg-8 order-last order-lg-first';
        } elseif ( 'left-sidebar' === $layout ) {
            $class = 'col-xx-9 col-lg-8';
        } else {
            $class = 'col-12';
        }
    } else {
        if ( 'right-sidebar' === $layout ) {
            $class = 'col-xl-8 mb-60 mb-xl-0';
        } elseif ( 'left-sidebar' === $layout ) {
            $class = 'col-xl-8 mb-60 mb-xl-0';
        } else {
            $class = 'col-12';
        }
    }

    $layout_arr = array(
        'layout' => $layout,
        'sidebar' => $sidebar,
        'class' => $class
    );

    return $layout_arr;

}

function irepair_insert_product_filter( $sidebar ) {
    if ( 'product-sidebar' === $sidebar ) {
        if ( is_active_sidebar( 'product-filter' ) ) :
            echo '<div class="widget widget-shopFilter">
                    <div class="widget__title mb-0">
                        <div class="widget__toggler"><i class="pix-icon-chevron2-top"></i></div>
                        <h4 class="h5">' . esc_html__( 'Filter', 'irepair' ) . '</h4>
                    </div>';
                    echo '<div class="widget__wrap">';
                    dynamic_sidebar( 'product-filter' );
                    echo '</div>';
            echo '</div>';
        endif;
    }
}

function irepair_show_sidebar( $layout, $sidebar ) {
    if ( ( function_exists( 'is_shop' ) && is_shop() ) || ( function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) ) {
        if ( isset( $layout ) && 'right-sidebar' === $layout ) {
            echo '<div class="col-xx-3 col-lg-4 mb-60 mb-lg-0"><aside class="sidebar">';
            if ( is_active_sidebar( $sidebar ) ) : dynamic_sidebar( $sidebar ); endif;
            irepair_insert_product_filter( $sidebar );
            echo '</aside></div>';
        } elseif ( isset( $layout ) && 'left-sidebar' === $layout ) {
            echo '<div class="col-xx-3 col-lg-4 mb-60 mb-lg-0"><aside class="sidebar">';
            if ( is_active_sidebar( $sidebar ) ) : dynamic_sidebar( $sidebar ); endif;
            irepair_insert_product_filter( $sidebar );
            echo '</aside></div>';
        } else {
            echo '';
        }
    } else {
        if ( isset( $layout ) && 'right-sidebar' === $layout ) {
            echo '<div class="col-xl-4"><aside class="sidebar ml-xl-30">';
            if ( is_active_sidebar( $sidebar ) ) : dynamic_sidebar( $sidebar ); endif;
            echo '</aside></div>';
        } elseif ( isset( $layout ) && 'left-sidebar' === $layout ) {
            echo '<div class="col-xl-4 order-last order-xl-first"><aside class="sidebar mr-xl-30">';
            if ( is_active_sidebar( $sidebar ) ) : dynamic_sidebar( $sidebar ); endif;
            echo '</aside></div>';
        } else {
            echo '';
        }
    }

}

add_filter( 'wp_kses_allowed_html', 'irepair_kses_allowed_html', 10, 2 );
function irepair_kses_allowed_html( $tags, $context ) {

    $common_attr = array(
        'id'    => array(),
        'class' => array(),
        'style' => array(),
    );

    switch ( $context ) {

        case 'irepair-img':
            $tags = array(
                'img' => array(
                    'id'     => array(),
                    'class'  => array(),
                    'style'  => array(),
                    'src'    => array(),
                    'width'  => array(),
                    'height' => array(),
                    'alt'    => array(),
                    'sizes'  => array(),
                    'srcset' => array(),
                ),
            );
            break;

        case 'irepair-a':
            $tags = array(
                'a' => array(
                    'id'     => array(),
                    'class'  => array(),
                    'style'  => array(),
                    'href'   => array(),
                    'target' => array(),
                    'title'  => array(),
                    'rel'    => array(),
                ),
            );
            break;

        case 'irepair-default' :
            $tags = array(
                'a' => array(
                    'id'     => array(),
                    'class'  => array(),
                    'style'  => array(),
                    'href'   => array(),
                    'target' => array(),
                    'title'  => array(),
                    'rel'    => array(),
                ),
                'img' => array(
                    'id'     => array(),
                    'class'  => array(),
                    'style'  => array(),
                    'src'    => array(),
                    'width'  => array(),
                    'height' => array(),
                    'alt'    => array(),
                    'sizes'  => array(),
                    'srcset' => array(),
                ),
                'br' => array(),
                'ul' => array(
                    'id'    => array(),
                    'class' => array(),
                    'style' => array(),
                    'type'  => array(),
                ),
                'ol' => array(
                    'id'    => array(),
                    'class' => array(),
                    'style' => array(),
                    'type'  => array(),
                ),
                'h1'     => $common_attr,
                'h2'     => $common_attr,
                'h3'     => $common_attr,
                'h4'     => $common_attr,
                'h5'     => $common_attr,
                'h6'     => $common_attr,
                'div'    => $common_attr,
                'li'     => $common_attr,
                'strong' => $common_attr,
                'b'      => $common_attr,
                'span'   => $common_attr,
                'mark'   => $common_attr,
                'i'      => $common_attr,
                'del'    => $common_attr,
                'ins'    => $common_attr,
                'em'     => $common_attr,
                'sup'     => $common_attr,
            );
            break;
    }

    return $tags;

}

if ( ! function_exists( 'irepair_return_string_zero' ) ) {
    function irepair_return_string_zero() {
        return '0';
    }
}

function irepair_get_elementor_attachment_image_html( $settings = null, $id = null, $default = 'full'  ) {
    if ( empty( $settings ) || ! class_exists( '\Elementor\Group_Control_Image_Size' ) ) {
        return;
    }

    $thumbnail_html = '';

    if ( isset( $settings[ 'image_size_default' ] ) && '1' === $settings['image_size_default'] ) {
        $thumbnail_html = wp_get_attachment_image( $id, $default );
    } else {
        $settings['image_size'] = [
            'id' => $id,
        ];
        $thumbnail_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, 'image_size' );
    }
    ?>
    <?php echo wp_kses( $thumbnail_html, 'irepair-img' ); ?>
    <?php
}

if ( ! function_exists( 'irepair_get_staticblocks_array' ) ) :
    function irepair_get_staticblocks_array( $is_footer = false )
    {

        $args = array(
            'post_type' => 'pix-section',
            'post_status' => 'publish',
        );
        $staticBlocks = array();
        $staticBlocks['default'] = esc_html__( 'Select block', 'irepair' );
        $args['posts_per_page'] = -1;
        $staticBlocksData = get_posts( $args );
        foreach ( $staticBlocksData as $_block ) {
            $staticBlocks[$_block->ID] = $_block->post_title;
        }
        if ( $is_footer ) {
            $staticBlocks['empty'] = esc_html__( 'No Footer', 'irepair' );
        }
        return $staticBlocks;
    }
endif;

add_filter( 'wpcf7_autop_or_not', '__return_false' );

function irepair_limit_words( $string, $word_limit, $wrapper = '' ) {

    $wrapper_start = $wrapper_end = '';
    if (trim( $wrapper ) != '') {
        $wrapper_start = '<' . $wrapper . '>';
        $wrapper_end = '</' . $wrapper . '>';
    }

    // creates an array of words from $string (this will be our excerpt)
    // explode divides the excerpt up by using a space character

    $words = explode(' ', $string);

    // this next bit chops the $words array and sticks it back together
    // starting at the first word '0' and ending at the $word_limit
    // the $word_limit which is passed in the function will be the number
    // of words we want to use
    // implode glues the chopped up array back together using a space character
    if ( trim( $string ) == '' ) {
        return '';
    } else {
        return $wrapper_start . implode( ' ', array_slice( $words, 0, $word_limit ) ) . '...' . $wrapper_end;
    }
}
