<?php

function irepair_add_header_title_space( $pre_title ) {
    return ( empty( $pre_title ) ) ? '' : ' ';
}

function irepair_the_header_title() {

    global $post;
    $front_page_id = get_option( 'page_on_front' );
    $posts_page_id = get_option( 'page_for_posts' );

    if ( is_home() ) {
        if ( 'posts' === get_option( 'show_on_front' ) ) {
            $title = irepair_get_option( 'header_home_title', esc_html__( 'Blog', 'irepair' ) ) . single_tag_title( '', false );
        } elseif ( 'page' === get_option( 'show_on_front' ) ) {
            if ( $posts_page_id ) {
                $posts_page = get_post( $posts_page_id );
                $title = $posts_page->post_title;

            }
        }
    } elseif ( is_front_page() ) {
        if ( $front_page_id && is_page( $front_page_id ) ) {
            $front_page = get_post( $front_page_id );
            $title = $front_page->post_title;
        }
    } elseif ( is_tax( 'pix-portfolio-category' ) || is_post_type_archive( 'pix-portfolio' ) ) {
        $title = irepair_get_option( 'header_archive_portfolio_title', esc_html__( 'Portfolio', 'irepair' ) );
    } elseif ( is_tax( 'pix-service-category' ) || is_post_type_archive( 'pix-service' ) ) {
        $title = irepair_get_option( 'header_archive_service_title', esc_html__( 'Services', 'irepair' ) );
    } elseif ( is_post_type_archive() ) {
        if ( irepair_use_woo() && function_exists( 'is_shop' ) && is_shop() ) {
            $title = wc_get_page_id( 'shop' ) ? get_the_title( wc_get_page_id( 'shop' ) ) : '';

            if ( ! $title ) {
                $product_post_type = get_post_type_object( 'product' );
                $title = $product_post_type->labels->name;
            }
        } else {
            $title = sprintf( esc_html__( 'Archives: %s', 'irepair' ), post_type_archive_title( '', false ) );
        }
    } elseif ( is_tag() ) {
        $prefix_title = irepair_get_option( 'header_archive_tag_title', esc_html__( 'Tag:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . single_tag_title( '', false );
    } elseif ( is_author() ) {
        $prefix_title = irepair_get_option( 'header_archive_author_title', esc_html__( 'Author:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . get_the_author();
    } elseif ( is_year() ) {
        $prefix_title = irepair_get_option( 'header_archive_year_title', esc_html__( 'Year:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'irepair' ) );
    } elseif ( is_month() ) {
        $prefix_title = irepair_get_option( 'header_archive_month_title', esc_html__( 'Month:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . get_the_date( esc_html_x( 'F Y', 'monthly archives date format', 'irepair' ) );
    } elseif ( is_day() ) {
        $prefix_title = irepair_get_option( 'header_archive_day_title', esc_html__( 'Day:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . get_the_date( esc_html_x( 'F j, Y', 'daily archives date format', 'irepair' ) );
    } elseif ( is_search() ) {
        $prefix_title = irepair_get_option( 'header_search_title', esc_html__( 'Search results for:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . '"' . get_search_query() . '"';
    } elseif ( is_404() ) {
        $title = irepair_get_option( 'header_404_title', esc_html__( 'Page not found', 'irepair' ) );
    } elseif ( irepair_use_woo() && function_exists( 'is_product_taxonomy' ) && is_product_taxonomy() ) {
        $product_term = $GLOBALS['wp_query']->get_queried_object();
        if ( isset( $product_term ) ) {
            $product_taxonomy  = get_taxonomy( $product_term->taxonomy );
            $prefix_title = $product_taxonomy->labels->singular_name;
            $title = $prefix_title . single_term_title( ': ', false );
        }
    } elseif ( is_category() || is_tax() ) {
        $prefix_title = irepair_get_option( 'header_archive_category_title', esc_html__( 'Category:', 'irepair' ) );
        $title = $prefix_title . irepair_add_header_title_space( $prefix_title ) . single_cat_title( '', false );
    } elseif ( is_singular( 'post' ) ) {
        $title = irepair_get_option( 'header_single_blog_title' );
        if ( empty( $title ) ) {
            $title = get_the_title();
        }
    } elseif ( is_singular( 'pix-portfolio' ) ) {
        $title = irepair_get_option( 'header_single_portfolio_title' );
        if ( empty( $title ) ) {
            $title = get_the_title();
        }
    } elseif ( is_singular( 'pix-service' ) ) {
        $title = irepair_get_option( 'header_single_service_title' );
        if ( empty( $title ) ) {
            $title = get_the_title();
        }
    } elseif ( is_singular( 'product' ) ) {
        $title = irepair_get_option( 'header_single_product_title' );
        if ( empty( $title ) ) {
            $title = get_the_title();
        }
    } else {
        $title = get_the_title();
    }

    echo wp_kses( $title, 'irepair-default' );

}
