<?php

// Layout Settings
function irepair_page_settings( $post ) {

    $irepair_accent_color = irepair_get_option( 'accent_color', get_option( 'irepair_default_accent_color' ) );
    $irepair_compliment_color = irepair_get_option( 'compliment_color', get_option( 'irepair_default_compliment_color' ) );
    $irepair_section_bg_color = irepair_get_option( 'section_bg_color', get_option( 'irepair_default_section_bg_color' ) );
    $irepair_bg_color = irepair_get_option( 'bg_color', get_option( 'irepair_default_bg_color' ) );

	echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Accent Color', 'irepair' ) . '</strong></p>';
	$page_accent_color = get_post_meta( $post->ID, 'irepair_page_accent_color', true );
	echo '<input type="text" name="irepair_page_accent_color" value="' . esc_attr( $page_accent_color ) . '" class="pix-admin-color-field" data-default-color="' . esc_attr( $irepair_accent_color ) . '" />';

    echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Сompliment Color', 'irepair' ) . '</strong></p>';
    $page_compliment_color = get_post_meta( $post->ID, 'irepair_page_compliment_color', true );
    echo '<input type="text" name="irepair_page_compliment_color" value="' . esc_attr( $page_compliment_color ) . '" class="pix-admin-color-field" data-default-color="' . esc_attr( $irepair_compliment_color ) . '" />';

    echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Sections Background Color', 'irepair' ) . '</strong></p>';
    $page_section_bg_color = get_post_meta( $post->ID, 'irepair_page_section_bg_color', true );
    echo '<input type="text" name="irepair_page_section_bg_color" value="' . esc_attr( $page_section_bg_color ) . '" class="pix-admin-color-field" data-default-color="' . esc_attr( $irepair_section_bg_color ) . '" />';

    echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Background Color', 'irepair' ) . '</strong></p>';
    $page_bg_color = get_post_meta( $post->ID, 'irepair_page_bg_color', true );
    echo '<input type="text" name="irepair_page_bg_color" value="' . esc_attr( $page_bg_color ) . '" class="pix-admin-color-field" data-default-color="' . esc_attr( $irepair_bg_color ) . '" />';

	echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Header Logo', 'irepair' ) . '</strong></p>';

    // Get WordPress' media upload URL
    $upload_link = esc_url( get_upload_iframe_src( 'image', $post->ID ) );

    // See if there's a media id already saved as post meta
    $logo_id = get_post_meta( $post->ID, 'irepair_header_logo', true );
    ?>

    <input class="pix-thumb-id" name="irepair_header_logo" type="hidden" value="<?php echo esc_attr( $logo_id ); ?>" />

    <p class="hide-if-no-js pix-margin-top-xs">
        <button data-input="<?php echo esc_url( $upload_link ); ?>" class="btn pix-image-upload pix-btn-icon <?php if ( ! empty( $logo_id ) ) { echo 'hidden'; } ?>"><i class="far fa-image"></i><span><?php echo esc_html__( 'Upload image', 'irepair' ); ?></span></button>
        <button type="button" class="btn pix-image-delete pix-btn-icon <?php if ( empty( $logo_id )  ) { echo 'hidden'; } ?>"><i class="fas fa-trash-alt"></i></button>
    </p>

    <div class="pix-thumb-container">
        <?php if ( ! empty( $logo_id ) ) : ?>
            <?php $logo_url = wp_get_attachment_image_src( $logo_id, 'full' )[0]; ?>
            <img src="<?php echo esc_url( $logo_url ); ?>" alt="<?php echo esc_attr__( 'Logo', 'irepair' ); ?>" />
        <?php endif; ?>
    </div>
<?php
}

add_action( 'save_post', 'irepair_page_settings_save' );
function irepair_page_settings_save( $post_id ) {
	if ( ! empty( $_POST['extra_fields_nonce'] ) && ! wp_verify_nonce( $_POST['extra_fields_nonce'], __FILE__ ) ) return false;
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE  ) return false;
	if ( ! current_user_can( 'edit_post', $post_id ) ) return false;

	if( ! isset( $_POST['irepair_page_accent_color'] )
        && ! isset($_POST['irepair_page_compliment_color'] )
		&& ! isset($_POST['irepair_page_section_bg_color'] )
        && ! isset($_POST['irepair_page_bg_color'] )
        && ! isset($_POST['irepair_header_logo'] )
	) return false;

	$_POST['irepair_header_logo'] = trim( $_POST['irepair_header_logo'] );
	$_POST['irepair_page_accent_color'] = trim( $_POST['irepair_page_accent_color'] );
    $_POST['irepair_page_compliment_color'] = trim( $_POST['irepair_page_compliment_color'] );
    $_POST['irepair_page_section_bg_color'] = trim( $_POST['irepair_page_section_bg_color'] );
    $_POST['irepair_page_bg_color'] = trim( $_POST['irepair_page_bg_color'] );


	if ( ! isset( $_POST['irepair_page_accent_color'] ) ) {
		delete_post_meta( $post_id, 'irepair_page_accent_color' );
	} else {
		update_post_meta( $post_id, 'irepair_page_accent_color', $_POST['irepair_page_accent_color'] );
	}

    if ( ! isset( $_POST['irepair_page_compliment_color'] ) ) {
        delete_post_meta( $post_id, 'irepair_page_compliment_color' );
    } else {
        update_post_meta( $post_id, 'irepair_page_compliment_color', $_POST['irepair_page_compliment_color'] );
    }

    if ( ! isset( $_POST['irepair_page_section_bg_color'] ) ) {
        delete_post_meta( $post_id, 'irepair_page_section_bg_color' );
    } else {
        update_post_meta( $post_id, 'irepair_page_section_bg_color', $_POST['irepair_page_section_bg_color'] );
    }

    if ( ! isset( $_POST['irepair_page_bg_color'] ) ) {
        delete_post_meta( $post_id, 'irepair_page_bg_color' );
    } else {
        update_post_meta( $post_id, 'irepair_page_bg_color', $_POST['irepair_page_bg_color'] );
    }

	if ( ! isset( $_POST['irepair_header_logo'] ) ) {
		delete_post_meta( $post_id, 'irepair_header_logo' );
	} else {
		update_post_meta( $post_id, 'irepair_header_logo', $_POST['irepair_header_logo'] );
	}

	return $post_id;
}

// Sidebar Settings

function irepair_page_layout() {
	global $wp_registered_sidebars;

    //HEADER
    $selected_header_color = get_post_meta( get_the_ID(), 'irepair_header_color', true ) == "" ? 'global' : get_post_meta( get_the_ID(), 'irepair_header_color', true );
    ?>

    <p><strong><?php echo esc_html__( 'Header text color', 'irepair' ); ?></strong></p>

    <select class="pix-sidebar-select" name="irepair_header_color" id="irepair_header_color">
        <option value="global" <?php if ( 'global' === $selected_header_color ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Global Settings', 'irepair' ); ?></option>
        <option value="text-default" <?php if ( 'text-default' === $selected_header_color ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Default (Black)', 'irepair' ); ?></option>
        <option value="text-inverse" <?php if ( 'text-inverse' === $selected_header_color ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Inverse', 'irepair' ); ?></option>
    </select>

    <?php
	// SIDEBAR
	$selected_layout = get_post_meta( get_the_ID(), 'irepair_page_layout', true ) == "" ? 'global' : get_post_meta( get_the_ID(), 'irepair_page_layout', true );

    // SIDEBAR CONTENT
    $selected_sidebar = get_post_meta( get_the_ID(), 'irepair_page_sidebar', true ) == "" ? 'global' : get_post_meta( get_the_ID(), 'irepair_page_sidebar', true );

    $irepair_sidebars = array( 'global' => esc_html__( 'Global Settings', 'irepair' ) );
    foreach( $wp_registered_sidebars as $key => $val ) {
        if ( $val['id'] !== 'product-filter' ) {
            $irepair_sidebars[$val['id']] = $val['name'];
        }
    }
	?>

	<p><strong><?php echo esc_html__( 'Sidebar', 'irepair' ); ?></strong></p>

	<select class="pix-sidebar-select" name="irepair_page_layout" id="irepair_page_layout">
		<option value="global" <?php if ( 'global' === $selected_layout ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Global Settings', 'irepair' ); ?></option>
		<option value="without-sidebar" <?php if ( 'without-sidebar' === $selected_layout ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Without Sidebar', 'irepair' ); ?></option>
		<option value="right-sidebar" <?php if ( 'right-sidebar' === $selected_layout ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Right Sidebar', 'irepair' ); ?></option>
		<option value="left-sidebar" <?php if ( 'left-sidebar' === $selected_layout ): ?>selected="selected"<?php endif; ?>><?php echo esc_html__( 'Left Sidebar', 'irepair' ); ?></option>
	</select>

	<p><strong><?php echo esc_html__( 'Sidebar Content', 'irepair' ); ?></strong></p>

    <select class="pix-sidebar-select" name="irepair_page_sidebar" id="irepair_page_sidebar" >
    <?php
    if ( is_array( $irepair_sidebars ) && ! empty( $irepair_sidebars ) ) {
        foreach( $irepair_sidebars as $key => $val ) {
            if ( $selected_sidebar == $key ) {
                echo '<option value="' . esc_attr( $key ) . '" selected>' . esc_html( $val ) . '</option>';
            } else {
                echo '<option value="' . esc_attr( $key ) . '">' . esc_html( $val ) . '</option>';
            }
        }
    }
    ?>
    </select>
    <?php
    // footer
    $selected_footer_block = ( get_post_meta( get_the_ID(), 'irepair_page_footer', true ) == "" ) ? 'global' : get_post_meta( get_the_ID(), 'irepair_page_footer', true );

    $args = array(
        'post_type'        => 'pix-section',
        'post_status'      => 'publish',
        'posts_per_page'   => -1
    );
    $static_blocks = array();
    $static_blocks['global'] = esc_html__( 'Use global settings', 'irepair' );
    $static_blocks['empty'] = esc_html__( 'No footer', 'irepair' );
    $static_blocksData = get_posts( $args );
    foreach( $static_blocksData as $_block ) {
        $static_blocks[$_block->ID] =  $_block->post_title;
    }

    ?>

    <p><strong><?php echo esc_html__( 'Footer Section', 'irepair' )?></strong></p>
    <ul>
        <li>
        <select class="pix-sidebar-select" name="irepair_page_footer" id="irepair_page_footer">
        <?php foreach( $static_blocks as $id => $static_block ) {
               echo "<option value='" . esc_attr( $id ) . "' ". selected( $selected_footer_block, $id, false ) .">" . esc_attr( $static_block ) . "</option>\n";
            }
        ?>
        </select>
        </li>
    </ul>

<?php }

add_action( 'save_post', 'irepair_save_page_layout' );
function irepair_save_page_layout( $post_id ) {
    if ( ! empty( $_POST['extra_fields_nonce'] ) && ! wp_verify_nonce( $_POST['extra_fields_nonce'], __FILE__ ) ) return false;
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE  ) return false;
    if ( ! current_user_can( 'edit_post', $post_id ) ) return false;

    if ( isset( $_POST['irepair_header_color'] ) ) {
        if ( get_post_meta( $post_id, 'irepair_header_color') == "" )
            add_post_meta( $post_id, 'irepair_header_color', $_POST['irepair_header_color'], true );
        else
            update_post_meta( $post_id, 'irepair_header_color', $_POST['irepair_header_color'] );
    }

    if ( isset( $_POST['irepair_page_layout'] ) ) {
        if ( get_post_meta( $post_id, 'irepair_page_layout') == "" )
            add_post_meta( $post_id, 'irepair_page_layout', $_POST['irepair_page_layout'], true );
        else
            update_post_meta( $post_id, 'irepair_page_layout', $_POST['irepair_page_layout'] );
    }

    if ( isset( $_POST['irepair_page_sidebar'] ) ) {
        if ( get_post_meta( $post_id, 'irepair_page_sidebar' ) == "" )
            add_post_meta( $post_id, 'irepair_page_sidebar', $_POST['irepair_page_sidebar'], true );
        else
            update_post_meta( $post_id, 'irepair_page_sidebar', $_POST['irepair_page_sidebar'] );
    }

    if ( isset( $_POST['irepair_page_footer'] ) ) {
        if ( get_post_meta( $post_id, 'irepair_page_footer' ) == "" )
            add_post_meta( $post_id, 'irepair_page_footer', $_POST['irepair_page_footer'], true );
        else
            update_post_meta( $post_id, 'irepair_page_footer', $_POST['irepair_page_footer'] );
    }

}

function irepair_portfolio_options( $post ) {

    echo '<p class="pix-margin-bottom-xs"><strong>' . esc_html__( 'Icon', 'irepair' ) . '</strong></p>';

    // Get WordPress' media upload URL
    $upload_link = esc_url( get_upload_iframe_src( 'image', $post->ID ) );

    // See if there's a media id already saved as post meta
    $icon_id = get_post_meta( $post->ID, 'irepair_project_icon', true );
    ?>

    <input class="pix-thumb-id" name="irepair_project_icon" type="hidden" value="<?php echo esc_attr( $icon_id); ?>" />

    <p class="hide-if-no-js pix-margin-top-xs">
        <button data-input="<?php echo esc_url( $upload_link ); ?>" class="btn pix-image-upload pix-btn-icon <?php if ( ! empty( $icon_id ) ) { echo 'hidden'; } ?>"><i class="far fa-image"></i><span><?php echo esc_html__( 'Upload image', 'irepair' ); ?></span></button>
        <button type="button" class="btn pix-image-delete pix-btn-icon <?php if ( empty( $icon_id )  ) { echo 'hidden'; } ?>"><i class="fas fa-trash-alt"></i></button>
    </p>

    <div class="pix-thumb-container">
        <?php if ( ! empty( $icon_id ) ) : ?>
            <?php $icon_url = wp_get_attachment_image_src( $icon_id, 'full' )[0]; ?>
            <img src="<?php echo esc_url( $icon_url ); ?>" alt="<?php echo esc_attr__( 'Icon', 'irepair' ); ?>" />
        <?php endif; ?>
    </div>

    <?php
}

add_action( 'save_post', 'pixtheme_portfolio_save' );
function pixtheme_portfolio_save( $post_id ) {
    if ( ! empty( $_POST['extra_fields_nonce'] ) && ! wp_verify_nonce( $_POST['extra_fields_nonce'], __FILE__ ) ) return false;
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE  ) return false;
    if ( ! current_user_can( 'edit_post', $post_id ) ) return false;

    if( ! isset( $_POST['irepair_project_icon'] )
    ) return false;

    $_POST['irepair_project_icon'] = trim( $_POST['irepair_project_icon'] );

    if ( ! isset( $_POST['irepair_project_icon'] ) ) {
        delete_post_meta( $post_id, 'irepair_project_icon' );
    } else {
        update_post_meta( $post_id, 'irepair_project_icon', $_POST['irepair_project_icon'] );
    }

    return $post_id;
}
