<?php

add_action( 'after_setup_theme', 'irepair_setup' );

if ( ! function_exists( 'irepair_setup' ) ) :

function irepair_setup() {

    // This theme styles the visual editor with editor-style.css to match the theme style.
    add_editor_style( 'assets/css/editor-style.css' );

    //Loading theme textdomain
    load_theme_textdomain( 'irepair', get_template_directory() . '/languages' );

    // This theme uses post thumbnails
    add_theme_support( 'post-thumbnails' );

    // Define various thumbnail sizes
    $img_size = ( ( irepair_get_option( 'image_base_size', '800' ) ) &&
                 is_numeric( irepair_get_option( 'image_base_size', '800' ) ) &&
                 irepair_get_option( 'image_base_size', '800' ) > 0
             ) ? irepair_get_option( 'image_base_size', '800' ) : 800;
    $img_landscape_ratio = ( ( irepair_get_option( 'image_landscape_ratio', '1.6' ) ) &&
                 is_numeric( irepair_get_option( 'image_landscape_ratio', '1.6' ) ) &&
                 irepair_get_option( 'image_landscape_ratio', '1.6' ) > 0
             ) ? irepair_get_option( 'image_landscape_ratio', '1.6' ) : 1.6;
    $img_portrait_ratio = ( ( irepair_get_option( 'image-portrait_ratio', '1.3' ) ) &&
                 is_numeric( irepair_get_option( 'image-portrait_ratio', '1.3' ) ) &&
                 irepair_get_option( 'image-portrait_ratio', '1.3' ) > 0
             ) ? irepair_get_option( 'image-portrait_ratio', '1.3' ) : 1.3;

    add_image_size( 'irepair-square-thumb', $img_size, $img_size, true );
    add_image_size( 'irepair-landscape-thumb', $img_size , $img_size/$img_landscape_ratio, true );
    add_image_size( 'irepair-portrait-thumb', $img_size, $img_size*$img_portrait_ratio, true );
    add_image_size( 'irepair-original-thumb', $img_size, 0 );
    add_image_size( 'irepair-product-thumb', $img_size, $img_size, false );

    add_image_size( 'irepair-post-thumb-large', 1440, 640, true );
    add_image_size( 'irepair-post-thumb-medium', 950, 420, true );
    add_image_size( 'irepair-post-thumb-small', 530, 370, true );
    add_image_size( 'irepair-thumb-small', 160, 160, false );
    add_image_size( 'irepair-thumb-mini', 20, 20, true );
    add_image_size( 'irepair-thumb-limit-height-small', 0, 80 );

    // support title-tag for Wordpress 4.1+
    add_theme_support( 'title-tag' );

    // Add default posts and comments RSS feed links to head
    add_theme_support( 'automatic-feed-links' );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array( 'search-form', 'gallery', 'caption' ) );

    // custom menu support
    if ( function_exists( 'register_nav_menus' ) ) {
        register_nav_menus( array ( 'primary_nav' => esc_html__( 'Primary Navigation', 'irepair' ) ) );
    }

    // Set content-width.
    global $content_width;
    if ( ! isset( $content_width ) ) {
        $content_width = 1070;
    }

    $args = array(
        'flex-width' => true,
        'width' => 174,
        'flex-height' => true,
        'height' => 'auto',
        'default-image' => get_template_directory_uri() . '/img/logo.svg'
    );

    add_theme_support( 'custom-header', $args );


    $args = array(
        'default-color' => 'F8F8FF'
    );

    add_theme_support( 'custom-background', $args );

    if ( irepair_use_woo() ) {

        add_theme_support(
            'woocommerce',
            array(
                'single_image_width' => irepair_get_option( 'product_single_thumb_width', '950' ),
                'thumbnail_image_width' => irepair_get_option( 'product_archive_thumb_width', '350' ),
            )
        );

        add_theme_support( 'wc-product-gallery-slider' );

        if ( irepair_get_option( 'use_product_gallery_zoom', true ) && 'default' === irepair_get_option( 'product_images_style', 'custom' ) ) {
            add_theme_support( 'wc-product-gallery-zoom' );
        }

        if ( irepair_get_option( 'use_product_gallery_lightbox', true ) && 'default' === irepair_get_option( 'product_images_style', 'custom' ) ) {
            add_theme_support( 'wc-product-gallery-lightbox' );
        }

        if ( irepair_use_compare() ) {
            if ( empty( get_option( 'woosc_open_button', '' ) ) ) {
                update_option( 'woosc_open_button', '.pix-open-compare-btn' );
            }
        }

    }

}
endif;// irepair_setup

add_action( 'after_switch_theme', 'irepair_switch_theme_counter', 1 );
function irepair_switch_theme_counter() {
    $i = get_option( 'irepair_switch_theme_count' );

    if ( $i ) {
        $i++;
    } else {
        $i = 1;
    }

    update_option( 'irepair_switch_theme_count', $i );
}

// Disable Elementor Default Global Fonts & Colors
add_action( 'after_switch_theme', 'irepair_disable_elementor_default_global_fonts_color', 3 );
function irepair_disable_elementor_default_global_fonts_color() {
    global $pagenow;

    if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
        return;
    }

    $i = get_option( 'irepair_switch_theme_count' );

    if ( ! $i || $i <= 1 ) {

        update_option( 'elementor_disable_color_schemes', 'yes' );
        update_option( 'elementor_disable_typography_schemes', 'yes' );

    }
}
