<?php

if ( ! function_exists( 'irepair_init_sidebars' ) ) :

    add_action( 'widgets_init', 'irepair_init_sidebars' );

    function irepair_init_sidebars() {

        if ( function_exists( 'register_sidebar' ) ) {

            $before_widget  = '<div id="%1$s" class="%2$s widget">';
            $after_widget   = '</div>';
            $before_title   = '<h3 class="widget__title">';
            $after_title    = '</h3>';

            register_sidebar( array(
                'name' => esc_html__( 'Blog Sidebar', 'irepair' ),
                'id' => 'sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));

            register_sidebar( array(
                'name' => esc_html__( 'Page Sidebar', 'irepair' ),
                'id' => 'page-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));


            if ( irepair_use_portfolio() ) :
            register_sidebar( array(
                'name' => esc_html__( 'Portfolio Sidebar', 'irepair' ),
                'id' => 'portfolio-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));
            endif;

            if ( irepair_use_service() ) :
            register_sidebar( array(
                'name' => esc_html__( 'Service Sidebar', 'irepair' ),
                'id' => 'service-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));
            endif;

            if ( irepair_use_woo() ) :

            register_sidebar( array(
                'name' => esc_html__( 'Product Sidebar', 'irepair' ),
                'id' => 'product-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));

            register_sidebar( array(
                'name' => esc_html__( 'Product Bottom Sidebar', 'irepair' ),
                'id' => 'product-calc-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));

            register_sidebar( array(
                'name' => esc_html__( 'Products Filter', 'irepair' ),
                'id' => 'product-filter',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));

            endif;

            register_sidebar( array(
                'name' => esc_html__( 'Custom Sidebar', 'irepair' ),
                'id' => 'custom-sidebar',
                'before_widget' => $before_widget,
                'after_widget' => $after_widget,
                'before_title' => $before_title,
                'after_title' => $after_title,
            ));

        }
    }

endif;

add_action( 'in_widget_form', 'irepair_in_widget_form', 10, 3 );
function irepair_in_widget_form( $widget, $return, $instance ) {
    $defaults = array(
        'bg-color' => 'bg-default',
        'outside_title' => ''
    );
    $instance = wp_parse_args( (array)$instance, $defaults );
    ?>

    <p class="pix-widget-field-outside-title">
        <label for="<?php echo esc_attr( $widget->get_field_id( 'outside_title' ) ); ?>"><?php esc_html_e( 'Title before Widget', 'irepair' ); ?></label>
        <input id="<?php echo esc_attr( $widget->get_field_id( 'outside_title' ) ); ?>" type="text" name="<?php echo esc_attr( $widget->get_field_name( 'outside_title' ) ); ?>" value="<?php echo esc_attr( $instance['outside_title'] ); ?>" class="widefat" />
    </p>

    <p class="pix-widget-field-bg-color">
        <label for="<?php echo esc_attr( $widget->get_field_id( 'bg-color' ) ); ?>"><?php esc_html_e( 'Background color:', 'irepair' ); ?></label>
        <select name="<?php echo esc_attr( $widget->get_field_name( 'bg-color' ) ); ?>" id="<?php echo esc_attr( $widget->get_field_id( 'bg-color' ) ); ?>" class="widefat">
            <option value="bg-default"<?php selected( $instance['bg-color'], 'bg-default' ); ?>><?php esc_html_e( 'Default background', 'irepair' ); ?></option>
            <option value="bg-4"<?php selected( $instance['bg-color'], 'bg-4' ); ?>><?php esc_html_e( 'Additional background', 'irepair' ); ?></option>
        </select>
    </p>
    <?php
}

add_filter( 'widget_update_callback', 'irepair_widget_update_callback', 10, 3 );
function irepair_widget_update_callback( $instance, $new_instance, $old_instance ) {
    $instance['outside_title'] = sanitize_text_field( $new_instance['outside_title'] );

    if ( in_array( $new_instance['bg-color'], array( 'bg-default', 'bg-4' ) ) ) {
        $instance['bg-color'] = $new_instance['bg-color'];
    } else {
        $instance['bg-color'] = 'bg-default';
    }
    return $instance;
}

add_filter( 'widget_display_callback', 'irepair_widget_display_callback', 10, 3 );
function irepair_widget_display_callback( $instance, $widget, $args ) {
    $outside_title  = empty( $instance['outside_title'] ) ? '' : $instance['outside_title'];
    $bg_color_class  = empty( $instance['bg-color'] ) ? 'bg-default' : $instance['bg-color'];

    $widget_classname = $widget->widget_options['classname'];

    $args['before_widget'] = str_replace( $widget_classname, "{$widget_classname} {$bg_color_class}", $args['before_widget'] );

    if ( ! empty( $outside_title ) ) {
        $args['before_widget'] = $args['before_title'] . $outside_title . $args['after_title'] . $args['before_widget'];
    }

    $widget->widget( $args, $instance );

    return false;
}
