<?php
if ( irepair_use_woo() ) {
    add_filter( 'woocommerce_enqueue_styles', 'irepair_load_woo_styles' );
    function irepair_load_woo_styles( $styles ) {
        if ( isset( $styles['woocommerce-layout'] ) && isset( $styles['woocommerce-layout']['src'] ) ) {
            $styles['woocommerce-layout']['src'] = get_template_directory_uri() . '/assets/css/woocommerce-layout.css';
        }
        if ( isset( $styles['woocommerce-general'] ) && isset( $styles['woocommerce-general']['src'] ) ) {
            $styles['woocommerce-general']['src'] = get_template_directory_uri() . '/assets/css/woocommerce.css';
        }
        return $styles;
    }
}

add_action( 'wp_enqueue_scripts', 'irepair_register_swiper', 4 );
function irepair_register_swiper() {
    $theme_version = wp_get_theme()->get( 'Version' );

    wp_register_script( 'swiper', get_template_directory_uri() . '/assets/js/swiper.min.js', array( 'jquery', 'imagesloaded' ) , NULL, true );
    wp_register_script( 'irepair-swiper-options', get_template_directory_uri() . '/assets/js/swiper-options.js', array( 'jquery', 'swiper' ), $theme_version, true );
}

add_action( 'wp_enqueue_scripts', 'irepair_load_styles_scripts' );

if ( ! function_exists( 'irepair_load_styles_scripts' ) ) :

    function irepair_load_styles_scripts() {

        $theme_version = wp_get_theme()->get( 'Version' );

        wp_enqueue_style( 'irepair-style', get_stylesheet_uri(), array(), $theme_version );

        wp_enqueue_style( 'irepair-fonts', irepair_fonts_url(), array(), $theme_version, 'screen, all' );
        wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/fontawesome.css' );
        wp_enqueue_style( 'irepair-main', get_template_directory_uri() . '/assets/css/main.css', array(), null, 'screen, all' );
        wp_enqueue_style( 'irepair-dynamic-styles', admin_url( 'admin-ajax.php' ) . '?action=dynamic_styles&pageID=' . get_the_ID() );

        wp_enqueue_script( 'imagesloaded' );
        wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ) , NULL, true );
        wp_enqueue_script( 'swiper' );
        wp_enqueue_script( 'irepair-swiper-options' );
        wp_enqueue_script( 'ion-rangeSlider', get_template_directory_uri() . '/assets/js/ion.rangeSlider.min.js', array( 'jquery' ) , NULL, true );
        wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/assets/js/fancybox.min.js', array( 'jquery' ) , NULL, true );
        wp_enqueue_script( 'isotope-masonry', get_template_directory_uri() . '/assets/js/isotope.min.js', array( 'jquery' ) , NULL, true );
        wp_enqueue_script( 'irepair-main', get_template_directory_uri() . '/assets/js/main.js', array( 'jquery' ) , $theme_version, true );
        wp_enqueue_script( 'irepair-custom', get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ) , $theme_version, true );

        wp_localize_script( 'irepair-custom', 'irepairAjax', array( 'url' => admin_url( 'admin-ajax.php' ) ) );

        if ( irepair_use_woo() ) {
            wp_enqueue_script( 'irepair-woo-custom', get_template_directory_uri() . '/assets/js/woo-custom.js', array( 'jquery' ) , $theme_version, true );
        }

        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) { wp_enqueue_script( 'comment-reply' ); }
    }

endif;

function irepair_dynamic_styles() {
    include( get_template_directory() . '/engine/theme/dynamic-styles.php' );
    exit;
}
add_action( 'wp_ajax_dynamic_styles', 'irepair_dynamic_styles' );
add_action( 'wp_ajax_nopriv_dynamic_styles', 'irepair_dynamic_styles' );

add_action( 'admin_enqueue_scripts', 'irepair_load_admin_styles_scripts' );

if ( ! function_exists( 'irepair_load_admin_styles_scripts' ) ) :

    /* Load custom admin scripts & styles */
    function irepair_load_admin_styles_scripts() {

        $theme_version = wp_get_theme()->get( 'Version' );

        wp_enqueue_media();

        wp_enqueue_script( 'wp-color-picker' );

        wp_register_script( 'irepair-custom-admin', get_template_directory_uri() . '/assets/js/custom-admin.js', array( 'jquery', 'wp-color-picker' ), $theme_version, true );
        wp_localize_script( 'irepair-custom-admin', 'meta_image',
            array(
                'title' => esc_html__( 'Choose or Upload an Image', 'irepair' ),
                'button' => esc_html__( 'Use this image', 'irepair' )
            )
        );

        wp_enqueue_script( 'irepair-custom-admin' );

        if ( irepair_use_woo() ) {
            wp_enqueue_script( 'irepair-woo-custom-admin', get_template_directory_uri() . '/assets/js/woo-custom-admin.js', array( 'jquery' ), $theme_version, true );
        }

        wp_enqueue_style( 'wp-color-picker' );
        wp_enqueue_style( 'irepair-custom-admin', get_template_directory_uri() . '/assets/css/custom-admin.css', array(), $theme_version );
        wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/fontawesome.css', array(), null );

    }

endif;

add_action( 'customize_preview_init', 'irepair_customizer_preview' );

if ( ! function_exists( 'irepair_customizer_preview' ) ) :

    function irepair_customizer_preview() {

        $theme_version = wp_get_theme()->get( 'Version' );

        wp_enqueue_script( 'irepair-customizer-preview', get_template_directory_uri() . '/assets/js/customizer/customizer-preview.js', array( 'customize-preview', 'jquery' ), $theme_version, true );
        wp_localize_script( 'irepair-customizer-preview', 'irepair_customizer_ajax',
            array(
                'url'   => admin_url( 'admin-ajax.php' ),
                'nonce' => wp_create_nonce( 'irepair_customizer_ajax_nonce' ),
                'template' => get_template_directory_uri(),
                'accent_color' => get_option( 'irepair_default_accent_color' ),
                'compliment_color' => get_option( 'irepair_default_compliment_color' ),
                'additional_color' => get_option( 'irepair_default_additional_color' ),
                'section_bg_color' => get_option( 'irepair_default_section_bg_color' ),
                'bg_color' => get_option( 'irepair_default_bg_color' ),
                'white_color' => get_option( 'irepair_default_white_color' ),
                'black_color' => get_option( 'irepair_default_black_color' ),
                'button_bg_color' => get_option( 'irepair_default_button_bg_color' ),
                'button_color' => get_option( 'irepair_default_button_color' ),
                'button_border_color' => get_option( 'irepair_default_button_border_color' ),
                'header_bg_color' => get_option( 'irepair_default_header_bg_color' ),
                'header_opacity' => get_option( 'irepair_default_header_opacity' ),
                'submenu_bg_color' => get_option( 'irepair_default_submenu_bg_color' ),
                'header_hover_color' => get_option( 'irepair_default_header_hover_color' ),
            )
        );

    }

endif;

add_action( 'customize_controls_enqueue_scripts', 'irepair_customizer_controls' );

if ( ! function_exists( 'irepair_customizer_controls' ) ) :

    function irepair_customizer_controls() {

        $theme_version = wp_get_theme()->get( 'Version' );

        wp_enqueue_script( 'irepair-customize', get_template_directory_uri() . '/assets/js/customizer/customize.js', array( 'jquery' ), $theme_version, false );
        wp_enqueue_script( 'irepair-customizer-controls', get_template_directory_uri() . '/assets/js/customizer/customizer-controls.js', array( 'customize-controls', 'jquery' ), $theme_version, false );

    }

endif;