<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' );

$irepair_get_layout = irepair_get_layout();
$irepair_layout = $irepair_get_layout['layout'];
$irepair_sidebar = $irepair_get_layout['sidebar'];
$irepair_layout_class = $irepair_get_layout['class'];

$under_header_section_id = false;
$under_header_section_id = irepair_get_option( 'shop_under_header_block', 'default' );
?>

<?php if ( ( is_shop() || is_product_category() ) && irepair_use_section() && $under_header_section_id && $under_header_section_id != 'default' ) : ?>
    <section class="section mt-n90">
        <div class="container">
            <?php irepair_get_section_content( $under_header_section_id ); ?>
        </div>
    </section>
<?php endif; ?>

<section class="section catalog pt-80 pb-120">
    <div class="container">
        <div class="row">
            <?php irepair_show_sidebar( $irepair_layout, $irepair_sidebar ); ?>
            <div class="<?php echo esc_attr( $irepair_layout_class ); ?>">
            <?php
            if ( woocommerce_product_loop() ) {

                if ( function_exists( 'woocommerce_output_all_notices' ) ) {
                    woocommerce_output_all_notices();
                }

                /**
                 * Hook: woocommerce_before_shop_loop.
                 *
                 * @hooked irepair_woo_heading_wrapper_start - 5
                 * @hooked woocommerce_output_all_notices - 10 - remove
                 * @hooked woocommerce_result_count - 20
                 * @hooked woocommerce_catalog_ordering - 30
                 * @hooked irepair_woo_heading_wrapper_end - 40
                 */
                ?>

                <?php do_action( 'woocommerce_before_shop_loop' ); ?>

                <?php woocommerce_product_loop_start();

                if ( wc_get_loop_prop( 'total' ) ) {
                    while ( have_posts() ) {
                        the_post();

                        /**
                         * Hook: woocommerce_shop_loop.
                         */
                        do_action( 'woocommerce_shop_loop' );

                        wc_get_template_part( 'content', 'product' );
                    }
                }

                woocommerce_product_loop_end();

                /**
                 * Hook: woocommerce_after_shop_loop.
                 *
                 * @hooked woocommerce_pagination - 10
                 */
                do_action( 'woocommerce_after_shop_loop' );
            } else {
                /**
                 * Hook: woocommerce_no_products_found.
                 *
                 * @hooked wc_no_products_found - 10
                 */
                do_action( 'woocommerce_no_products_found' );
            }
            ?>
            </div>
        </div>
    </div>
</section>

<?php
get_footer( 'shop' );
