<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

// Ensure visibility.
if ( empty( $product ) || ! $product->is_visible() ) {
    return;
}

if ( array_key_exists( 'products_view', $_GET ) ) {
    $irepair_catalog_view = $_GET['products_view'];
} else {
    $irepair_catalog_view = 'cards';
}

?>
<?php if ( (is_shop() || is_product_category()) && 'cards' === $irepair_catalog_view ) : ?>
    <?php get_template_part( 'template-parts/woocommerce/content-product', 'icons-center' ); ?>
<?php elseif ( 'cards' === $irepair_catalog_view ) : ?>
    <div <?php wc_product_class( 'col', $product ); ?>>
        <div class="productCard">
            <div class="productCard__img">
                <?php echo woocommerce_get_product_thumbnail('irepair-product-thumb'); ?>
            </div>

            <div class="productCard__info">
                <div class="productCard__infoTitle"><a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a></div>
                <?php
                /**
                 * woocommerce_after_shop_loop_item_title hook.
                 *
                 * @hooked woocommerce_template_loop_rating - 5
                 * @hooked woocommerce_template_loop_price - 10
                 */
                do_action( 'woocommerce_after_shop_loop_item_title' );
                ?>
            </div>

            <div class="productCard__badges">
                <?php
                if ( function_exists( 'woocommerce_show_product_loop_sale_flash' ) ) {
                    woocommerce_show_product_loop_sale_flash();
                }
                ?>
            </div>

            <?php woocommerce_template_loop_product_link_open(); ?>
            <?php woocommerce_template_loop_product_link_close(); ?>

            <div class="productCard__icons">
                <?php irepair_get_archive_wishlist_button_template(); ?>
                <?php irepair_get_archive_compare_button_template(); ?>
                <?php irepair_get_quick_view_button_template(); ?>
                <?php woocommerce_template_loop_add_to_cart(); ?>
            </div>
        </div>
    </div>
<?php elseif ( 'list' === $irepair_catalog_view ) : ?>
    <?php get_template_part( 'template-parts/woocommerce/content-product', 'list' ); ?>
<?php endif;
