<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

/**
 * Hook: woocommerce_before_single_product.
 *
 * @hooked woocommerce_output_all_notices - 10
 */
do_action( 'woocommerce_before_single_product' );

if ( post_password_required() ) {
    echo get_the_password_form(); // WPCS: XSS ok.
    return;
}

$irepair_product_sku = ( $sku = $product->get_sku() ) ? $sku : esc_html__( 'N/A', 'irepair' );

$col_image_class = !irepair_get_option( 'product_image_width', false ) ? 'col-xy-8' : 'col-xy-7';
$col_desc_class = !irepair_get_option( 'product_image_width', false ) ? 'col-xy-4' : 'col-xy-5' ;

$col_attr_class = 'col-xy-12';
$col_calc_class = '';
if ( is_active_sidebar( 'product-calc-sidebar' ) && irepair_get_option( 'show_product_upsells', true ) ) {
    $col_attr_class = !irepair_get_option( 'product_image_width', false ) ? 'col-xy-8' : 'col-xy-7';
    $col_calc_class = !irepair_get_option( 'product_image_width', false ) ? 'col-xy-4' : 'col-xy-5' ;
}

?>
<div id="product-<?php the_ID(); ?>" <?php wc_product_class( 'fullprod', $product ); ?>>

    <div class="fullprod__body">
        <div class="row mb-30 mb-xy-0">
            <div class="<?php echo esc_attr($col_image_class)?> mb-40">
<!--                <div class="fullprod__header">-->
<!--                    <div class="d-flex flex-wrap justify-content-between align-items-center my-10 mr-sm-40">-->
<!--                        --><?php //if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>
<!--                            <div class="flex-shrink-0 mr-30"><span class="text-muted">--><?php //esc_html_e( 'SKU:', 'irepair' ); ?><!--</span> --><?php //echo esc_html( $irepair_product_sku ); ?><!--</div>-->
<!--                        --><?php //endif; ?>
<!--                        <div class="flex-shrink-0">-->
<!--                            --><?php
//                            if ( function_exists( 'woocommerce_template_single_rating' ) ) {
//                                woocommerce_template_single_rating();
//                            }
//                            ?>
<!--                        </div>-->
<!--                    </div>-->
<!--                    <div class="d-flex align-items-center">-->
<!--                        --><?php //if ( irepair_get_option( 'show_product_share', true ) && shortcode_exists( 'pix_share' )  ) : ?>
<!--                            <div class="fullprod__share">-->
<!--                                <div class="fullprod__shareBtn"></div>-->
<!--                                <div class="fullprod__shareSocial">-->
<!--                                    --><?php //echo do_shortcode( '[pix_share]' ); ?>
<!--                                </div>-->
<!--                            </div>-->
<!--                        --><?php //endif; ?>
<!--                    </div>-->
<!--                </div>-->
                <?php if ( 'custom' === irepair_get_option( 'product_images_style', 'custom' ) ) : ?>
                    <div class="fullprod__image-wrapper fullprod__image-custom-style">
                        <?php
                        if ( function_exists( 'woocommerce_show_product_sale_flash' ) ) :
                            woocommerce_show_product_sale_flash();
                        endif;
                        get_template_part( 'template-parts/woocommerce/single-product/product', 'custom-images' );
                        ?>
                    </div>
                <?php elseif ( 'default' === irepair_get_option( 'product_images_style', 'custom' ) ) : ?>
                    <div class="fullprod__image-wrapper fullprod__image-default-style">
                        <?php
                        /**
                         * Hook: woocommerce_before_single_product_summary.
                         *
                         * @hooked woocommerce_show_product_sale_flash - 10
                         * @hooked woocommerce_show_product_images - 20
                         */
                        do_action( 'woocommerce_before_single_product_summary' );
                        ?>
                    </div>
                <?php endif;  ?>
            </div>
            <div class="<?php echo esc_attr($col_desc_class)?> pl-xz-70">
                <div class="row row-cols-1 row-cols-lg-2 row-cols-xy-1">
                    <div class="col">
                        <div class="fullprod__info bg-3">
                            <?php
                                if ( in_array( irepair_get_option( 'header_style_prod', '' ), ['hide_title', 'hide_breadcrumbs'] ) ){
                                    the_title( '<h1 class="product_title entry-title">', '</h1>' );
                                }
                            ?>
                            <?php
                            if ( irepair_get_option( 'show_product_brand', true ) ) :
                                $product_brands = wp_get_object_terms( get_the_id(), 'pix-product-brand' );
                                if ( ! empty( $product_brands ) && ! is_wp_error( $product_brands ) ) {
                                    foreach ( $product_brands as $brand ) {
                                        $brand_thumbnail_id = get_term_meta( $brand->term_id, 'thumbnail_id', true );
                                        if ( ! empty( $brand_thumbnail_id ) ) {
                                            $brand_image_src = wp_get_attachment_image_src( $brand_thumbnail_id, 'irepair-thumb-limit-height-small' );
                                            if(isset($brand_image_src[0])){
                                                echo '<a class="fullprod__brand" href="' . esc_url( get_category_link( $brand->term_id ) ) . '">
                                                    <img src="' . esc_url( $brand_image_src[0] ) . '" alt="' . esc_attr( $brand->name ) . '" />
                                                </a>';
                                            }
                                        }
                                    }
                                }
                            endif;
                            ?>
                            <?php
                            /**
                             * Hook: woocommerce_single_product_summary.
                             *
                             * @hooked woocommerce_template_single_title - 5 - remove
                             * @hooked woocommerce_template_single_rating - 10 - remove
                             * @hooked woocommerce_template_single_price - 10
                             * @hooked woocommerce_template_single_excerpt - 20
                             * @hooked woocommerce_template_single_add_to_cart - 30
                             * @hooked woocommerce_template_single_meta - 40 - remove
                             * @hooked woocommerce_template_single_sharing - 50
                             * @hooked WC_Structured_Data::generate_product_data() - 60
                             */
                            do_action( 'woocommerce_single_product_summary' );
                            ?>
                        </div>
                    </div>
                    <div class="col">
                        <div class="fullprod__info bg-2">
                            <?php
                            if ( function_exists( 'woocommerce_template_single_meta' ) ) {
                                woocommerce_template_single_meta();
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="<?php echo esc_attr($col_attr_class)?>">
                <?php
                /**
                 * Hook: woocommerce_after_single_product_summary.
                 *
                 * @hooked woocommerce_output_product_data_tabs - 10
                 * @hooked woocommerce_upsell_display - 15 - remove
                 * @hooked woocommerce_output_related_products - 20 -remove
                 */
                if ( irepair_get_option( 'show_product_tabs', true ) ) :
                    do_action( 'woocommerce_after_single_product_summary' );
                endif;
                ?>
            </div>
            <?php if ( is_active_sidebar( 'product-calc-sidebar' ) && irepair_get_option( 'show_product_upsells', true ) ) : ?>
            <div class="<?php echo esc_attr($col_calc_class)?> pl-xz-50">
                <?php if ( ! empty( $irepair_product_support_text = irepair_get_option( 'product_support_text' ) ) ) : ?>
                    <div class="fullprod__support">
                        <?php echo wp_kses( $irepair_product_support_text, 'irepair-default' ); ?>
                    </div>
                <?php endif; ?>
                <?php
                    echo '<div class="pix-calc-sidebar">';
                    dynamic_sidebar( 'product-calc-sidebar' );
                    echo '</div>';
                ?>
            </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php do_action( 'woocommerce_after_single_product' ); ?>
